@@ -116,7 +116,7 @@ import weka.filters.unsupervised.attribute.ReplaceMissingValues;
  <!-- options-end -->
  *
  * @author  Benedikt Waldvogel (mail at bwaldvogel.de)
- * @version $Revision: 4856 $
+ * @version $Revision: 5917 $
  */
 public class LibLINEAR
   extends Classifier
@@ -932,6 +932,7 @@ public class LibLINEAR
 
       setField(result, "l", Integer.valueOf(vy.size()));
       setField(result, "n", Integer.valueOf(max_index));
+      setField(result, "bias", getBias());
 
       newArray(result, "x", Class.forName(CLASS_FEATURENODE), new int[]{vy.size(), 0});
       for (int i = 0; i < vy.size(); i++)
@@ -1086,6 +1087,7 @@ public class LibLINEAR
    */
   public Capabilities getCapabilities() {
     Capabilities result = super.getCapabilities();
+    result.disableAll();
 
     // attributes
     result.enable(Capability.NOMINAL_ATTRIBUTES);
@@ -1221,7 +1223,7 @@ public class LibLINEAR
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 4856 $");
+    return RevisionUtils.extract("$Revision: 5917 $");
   }
 
   /**
