@@ -53,7 +53,7 @@ import java.util.Vector;
  <!-- options-end -->
  *
  * @author  Remco Bouckaert (remco@cs.waikato.ac.nz,rrb@xm.co.nz)
- * @version $Revision: 6622 $
+ * @version $Revision: 11614 $
  */
 public class RegOptimizer 
   implements OptionHandler, Serializable, RevisionHandler {
@@ -117,7 +117,7 @@ public class RegOptimizer
   protected SMOset m_supportVectors;
   
   /** number of kernel evaluations, used for printing statistics only **/
-  protected int m_nEvals = 0;
+  protected long m_nEvals = 0;
 
   /** number of kernel cache hits, used for printing statistics only **/
   protected int m_nCacheHits = -1;
@@ -259,7 +259,7 @@ public class RegOptimizer
    * 
    * @return		the number of kernel evaluations
    */
-  public int getKernelEvaluations() {
+  public long getKernelEvaluations() {
     return m_nEvals;
   }
 
@@ -558,6 +558,6 @@ public class RegOptimizer
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 6622 $");
+    return RevisionUtils.extract("$Revision: 11614 $");
   }
 }
