@@ -149,7 +149,7 @@ import weka.core.WeightedInstancesHandler;
  * @author Eibe Frank (eibe@cs.waikato.ac.nz)
  * @author Len Trigg (len@reeltwo.com)
  * @author Richard Kirkby (rkirkby@cs.waikato.ac.nz)
- * @version $Revision: 9370 $
+ * @version $Revision: 11572 $
  */
 public class Bagging extends RandomizableIteratedSingleClassifierEnhancer
     implements WeightedInstancesHandler, AdditionalMeasureProducer,
@@ -497,7 +497,7 @@ public class Bagging extends RandomizableIteratedSingleClassifierEnhancer
           + "out-of-bag error is to be calculated!");
     }
 
-    int bagSize = data.numInstances() * m_BagSizePercent / 100;
+    int bagSize = (int) (data.numInstances() * (m_BagSizePercent / 100.0));
     Random random = new Random(m_Seed);
 
     boolean[][] inBag = null;
@@ -553,7 +553,7 @@ public class Bagging extends RandomizableIteratedSingleClassifierEnhancer
           // double pred = m_Classifiers[j].classifyInstance(data.instance(i));
           if (numeric) {
             // votes[0] += pred;
-            votes[0] = m_Classifiers[j].classifyInstance(data.instance(i));
+            votes[0] += m_Classifiers[j].classifyInstance(data.instance(i));
           } else {
             // votes[(int) pred]++;
             double[] newProbs = m_Classifiers[j].distributionForInstance(data
@@ -659,7 +659,7 @@ public class Bagging extends RandomizableIteratedSingleClassifierEnhancer
    */
   @Override
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 9370 $");
+    return RevisionUtils.extract("$Revision: 11572 $");
   }
 
   /**
