@@ -32,14 +32,10 @@ import weka.core.Instances;
 import weka.core.Option;
 import weka.core.RevisionHandler;
 import weka.core.RevisionUtils;
-import weka.core.TechnicalInformation;
-import weka.core.TechnicalInformationHandler;
 import weka.core.UnsupportedClassTypeException;
 import weka.core.Utils;
 import weka.core.WeightedInstancesHandler;
 import weka.core.Capabilities.Capability;
-import weka.core.TechnicalInformation.Field;
-import weka.core.TechnicalInformation.Type;
 
 import java.io.Serializable;
 import java.util.Enumeration;
@@ -48,7 +44,7 @@ import java.util.Vector;
 
 /**
  <!-- globalinfo-start -->
- * The implementation of a RIpple-DOwn Rule learner.<br/>
+ * An implementation of a RIpple-DOwn Rule learner.<br/>
  * <br/>
  * It generates a default rule first and then the exceptions for the default rule with the least (weighted) error rate.  Then it generates the "best" exceptions for each exception and iterates until pure.  Thus it performs a tree-like expansion of exceptions.The exceptions are a set of rules that predict classes other than the default. IREP is used to generate the exceptions.<br/>
  * <br/>
@@ -58,23 +54,6 @@ import java.util.Vector;
  * <p/>
  <!-- globalinfo-end -->
  *
- <!-- technical-bibtex-start -->
- * BibTeX:
- * <pre>
- * &#64;article{Gaines1995,
- *    author = {Brian R. Gaines and Paul Compton},
- *    journal = {J. Intell. Inf. Syst.},
- *    number = {3},
- *    pages = {211-228},
- *    title = {Induction of Ripple-Down Rules Applied to Modeling Large Databases},
- *    volume = {5},
- *    year = {1995},
- *    PDF = {http://pages.cpsc.ucalgary.ca/\~gaines/reports/ML/JIIS95/JIIS95.pdf}
- * }
- * </pre>
- * <p/>
- <!-- technical-bibtex-end -->
- * 
  * There are five inner classes defined in this class. <br>
  * The first is Ridor_node, which implements one node in the Ridor tree.  It's basically
  * composed of a default class and a set of exception rules to the default class.<br>
@@ -119,12 +98,11 @@ import java.util.Vector;
  <!-- options-end -->
  *
  * @author Xin XU (xx5@cs.waikato.ac.nz)
- * @version $Revision: 1.21 $ 
+ * @version $Revision: 5529 $ 
  */
 public class Ridor 
   extends Classifier
-  implements AdditionalMeasureProducer, WeightedInstancesHandler,
-             TechnicalInformationHandler {
+  implements AdditionalMeasureProducer, WeightedInstancesHandler {
 
   /** for serialization */
   static final long serialVersionUID = -7261533075088314436L;
@@ -165,38 +143,14 @@ public class Ridor
    * displaying in the explorer/experimenter gui
    */
   public String globalInfo() {
-    return "The implementation of a RIpple-DOwn Rule learner.\n\n" 
+    return "An implementation of a RIpple-DOwn Rule learner.\n\n" 
       + "It generates a default rule first and then the exceptions for the default rule "
       + "with the least (weighted) error rate.  Then it generates the \"best\" exceptions for "
       + "each exception and iterates until pure.  Thus it performs a tree-like expansion of "
       + "exceptions."
       + "The exceptions are a set of rules that predict classes other than the default. "
       + "IREP is used to generate the exceptions.\n\n"
-      + "For more information about Ripple-Down Rules, see:\n\n"
-      + getTechnicalInformation().toString();
-  }
-
-  /**
-   * Returns an instance of a TechnicalInformation object, containing 
-   * detailed information about the technical background of this class,
-   * e.g., paper reference or book this class is based on.
-   * 
-   * @return the technical information about this class
-   */
-  public TechnicalInformation getTechnicalInformation() {
-    TechnicalInformation 	result;
-    
-    result = new TechnicalInformation(Type.ARTICLE);
-    result.setValue(Field.AUTHOR, "Brian R. Gaines and Paul Compton");
-    result.setValue(Field.YEAR, "1995");
-    result.setValue(Field.TITLE, "Induction of Ripple-Down Rules Applied to Modeling Large Databases");
-    result.setValue(Field.JOURNAL, "J. Intell. Inf. Syst.");
-    result.setValue(Field.VOLUME, "5");
-    result.setValue(Field.NUMBER, "3");
-    result.setValue(Field.PAGES, "211-228");
-    result.setValue(Field.PDF, "http://pages.cpsc.ucalgary.ca/~gaines/reports/ML/JIIS95/JIIS95.pdf");
-    
-    return result;
+      + "For more information about Ripple-Down Rules, see:\n\n";
   }
     
   /** 
@@ -556,7 +510,7 @@ public class Ridor
      * @return		the revision
      */
     public String getRevision() {
-      return RevisionUtils.extract("$Revision: 1.21 $");
+      return RevisionUtils.extract("$Revision: 5529 $");
     }
   }    
 
@@ -933,7 +887,7 @@ public class Ridor
      * @return		the revision
      */
     public String getRevision() {
-      return RevisionUtils.extract("$Revision: 1.21 $");
+      return RevisionUtils.extract("$Revision: 5529 $");
     }
   }
     
@@ -997,7 +951,7 @@ public class Ridor
      * @return		the revision
      */
     public String getRevision() {
-      return RevisionUtils.extract("$Revision: 1.21 $");
+      return RevisionUtils.extract("$Revision: 5529 $");
     }
   }
     
@@ -1183,7 +1137,7 @@ public class Ridor
      * @return		the revision
      */
     public String getRevision() {
-      return RevisionUtils.extract("$Revision: 1.21 $");
+      return RevisionUtils.extract("$Revision: 5529 $");
     }
   }
     
@@ -1303,7 +1257,7 @@ public class Ridor
      * @return		the revision
      */
     public String getRevision() {
-      return RevisionUtils.extract("$Revision: 1.21 $");
+      return RevisionUtils.extract("$Revision: 5529 $");
     }
   }
 
@@ -1314,6 +1268,7 @@ public class Ridor
    */
   public Capabilities getCapabilities() {
     Capabilities result = super.getCapabilities();
+    result.disableAll();
 
     // attributes
     result.enable(Capability.NOMINAL_ATTRIBUTES);
@@ -1349,6 +1304,8 @@ public class Ridor
 	
     int index = data.classIndex();
     m_Cover = data.sumOfWeights();
+
+    m_Random = new Random(m_Seed);
 	
     /* Create a binary attribute */
     FastVector binary_values = new FastVector(2);
@@ -1682,7 +1639,7 @@ public class Ridor
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 1.21 $");
+    return RevisionUtils.extract("$Revision: 5529 $");
   }
     
   /**
