@@ -71,7 +71,7 @@ import weka.core.TechnicalInformation.Type;
  <!-- options-end -->
  *
  * @author Richard Kirkby
- * @version $Revision: 8127 $
+ * @version $Revision: 10279 $
 */
 
 public class LADTree
@@ -1121,7 +1121,7 @@ public class LADTree
 	PredictionNode child = split.getChildForBranch(i);
 	if (child != null) {
 	  text.append("S" + split.orderAdded + "->" + "S" + split.orderAdded + "P" + i +
-		      " [label=\"" + split.comparisonString(i) + "\"]\n");
+		      " [label=\"" + Utils.backQuoteChars(split.comparisonString(i)) + "\"]\n");
 	  graphTraverse(child, text, split.orderAdded, i);
 	}
       }
@@ -1466,7 +1466,7 @@ public class LADTree
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 8127 $");
+    return RevisionUtils.extract("$Revision: 10279 $");
   }
 
   /**
