@@ -77,7 +77,7 @@ import java.util.Vector;
  <!-- options-end -->
  *
  * @author Eibe Frank (eibe@cs.waikato.ac.nz)
- * @version $Revision: 9389 $ 
+ * @version $Revision: 10275 $ 
  */
 public class REPTree 
   extends Classifier 
@@ -350,12 +350,12 @@ public class REPTree
       num++;
       if (m_Attribute == -1) {
 	text.append("N" + Integer.toHexString(Tree.this.hashCode()) +
-		    " [label=\"" + num + leafString(parent) +"\"" +
+		    " [label=\"" + num + Utils.backQuoteChars(leafString(parent)) +"\"" +
 		    "shape=box]\n");
       } else {
 	text.append("N" + Integer.toHexString(Tree.this.hashCode()) +
 		    " [label=\"" + num + ": " + 
-		    m_Info.attribute(m_Attribute).name() + 
+		    Utils.backQuoteChars(m_Info.attribute(m_Attribute).name()) + 
 		    "\"]\n");
 	for (int i = 0; i < m_Successors.length; i++) {
 	  text.append("N" + Integer.toHexString(Tree.this.hashCode()) 
@@ -372,7 +372,7 @@ public class REPTree
 			  Utils.doubleToString(m_SplitPoint, 2));
 	    }
 	  } else {
-	    text.append(" = " + m_Info.attribute(m_Attribute).value(i));
+	    text.append(" = " + Utils.backQuoteChars(m_Info.attribute(m_Attribute).value(i)));
 	  }
 	  text.append("\"]\n");
 	  num = m_Successors[i].toGraph(text, num, this);
@@ -1341,7 +1341,7 @@ public class REPTree
      * @return		the revision
      */
     public String getRevision() {
-      return RevisionUtils.extract("$Revision: 9389 $");
+      return RevisionUtils.extract("$Revision: 10275 $");
     }
   }
 
@@ -1972,7 +1972,7 @@ public class REPTree
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 9389 $");
+    return RevisionUtils.extract("$Revision: 10275 $");
   }
 
   /**
