@@ -33,7 +33,7 @@ import weka.core.Capabilities.Capability;
  * be pruned using C4.5 procedures.
  *
  * @author Eibe Frank (eibe@cs.waikato.ac.nz)
- * @version $Revision: 5535 $
+ * @version $Revision: 8986 $
  */
 
 public class C45PruneableClassifierTree 
@@ -119,7 +119,7 @@ public class C45PruneableClassifierTree
     data = new Instances(data);
     data.deleteWithMissingClass();
     
-   buildTree(data, m_subtreeRaising);
+   buildTree(data, m_subtreeRaising || !m_cleanup);
    collapse();
    if (m_pruneTheTree) {
      prune();
@@ -229,7 +229,7 @@ public class C45PruneableClassifierTree
     C45PruneableClassifierTree newTree = 
       new C45PruneableClassifierTree(m_toSelectModel, m_pruneTheTree, m_CF,
 				     m_subtreeRaising, m_cleanup);
-    newTree.buildTree((Instances)data, m_subtreeRaising);
+    newTree.buildTree((Instances)data, m_subtreeRaising || !m_cleanup);
 
     return newTree;
   }
@@ -368,6 +368,6 @@ public class C45PruneableClassifierTree
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 5535 $");
+    return RevisionUtils.extract("$Revision: 8986 $");
   }
 }
