@@ -35,7 +35,7 @@ import java.util.Random;
  * be pruned using a pruning set. 
  *
  * @author Eibe Frank (eibe@cs.waikato.ac.nz)
- * @version $Revision: 5535 $
+ * @version $Revision: 8985 $
  */
 public class PruneableClassifierTree 
   extends ClassifierTree {
@@ -123,7 +123,7 @@ public class PruneableClassifierTree
    Random random = new Random(m_seed);
    data.stratify(numSets);
    buildTree(data.trainCV(numSets, numSets - 1, random),
-	     data.testCV(numSets, numSets - 1), false);
+	     data.testCV(numSets, numSets - 1), !m_cleanup);
    if (pruneTheTree) {
      prune();
    }
@@ -172,7 +172,7 @@ public class PruneableClassifierTree
     PruneableClassifierTree newTree = 
       new PruneableClassifierTree(m_toSelectModel, pruneTheTree, numSets, m_cleanup,
 				  m_seed);
-    newTree.buildTree(train, test, false);
+    newTree.buildTree(train, test, !m_cleanup);
     return newTree;
   }
 
@@ -235,6 +235,6 @@ public class PruneableClassifierTree
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 5535 $");
+    return RevisionUtils.extract("$Revision: 8985 $");
   }
 }
