@@ -1,17 +1,16 @@
 /*
- *    This program is free software; you can redistribute it and/or modify
- *    it under the terms of the GNU General Public License as published by
- *    the Free Software Foundation; either version 2 of the License, or
- *    (at your option) any later version.
+ *   This program is free software: you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation, either version 3 of the License, or
+ *   (at your option) any later version.
  *
- *    This program is distributed in the hope that it will be useful,
- *    but WITHOUT ANY WARRANTY; without even the implied warranty of
- *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *    GNU General Public License for more details.
+ *   This program is distributed in the hope that it will be useful,
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *   GNU General Public License for more details.
  *
- *    You should have received a copy of the GNU General Public License
- *    along with this program; if not, write to the Free Software
- *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   You should have received a copy of the GNU General Public License
+ *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
@@ -63,7 +62,9 @@ import java.util.Vector;
 
 /**
  <!-- globalinfo-start -->
- * Mihael Ankerst, Markus M. Breunig, Hans-Peter Kriegel, Joerg Sander: OPTICS: Ordering Points To Identify the Clustering Structure. In: ACM SIGMOD International Conference on Management of Data, 49-60, 1999.
+ * Basic implementation of OPTICS clustering algorithm that should *not* be used as a reference for runtime benchmarks: more sophisticated implementations exist! Clustering of new instances is not supported. More info:<br/>
+ * <br/>
+ *  Mihael Ankerst, Markus M. Breunig, Hans-Peter Kriegel, Joerg Sander: OPTICS: Ordering Points To Identify the Clustering Structure. In: ACM SIGMOD International Conference on Management of Data, 49-60, 1999.
  * <p/>
  <!-- globalinfo-end -->
  *
@@ -95,7 +96,7 @@ import java.util.Vector;
  *  index (database) used for OPTICS (default = weka.clusterers.forOPTICSAndDBScan.Databases.SequentialDatabase)</pre>
  * 
  * <pre> -D &lt;String&gt;
- *  distance-type (default = weka.clusterers.forOPTICSAndDBScan.DataObjects.EuclidianDataObject)</pre>
+ *  distance-type (default = weka.clusterers.forOPTICSAndDBScan.DataObjects.EuclideanDataObject)</pre>
  * 
  * <pre> -F
  *  write results to OPTICS_#TimeStamp#.TXT - File</pre>
@@ -115,7 +116,7 @@ import java.util.Vector;
  * @author Matthias Schubert (schubert@dbs.ifi.lmu.de)
  * @author Zhanna Melnikova-Albrecht (melnikov@cip.ifi.lmu.de)
  * @author Rainer Holzmann (holzmann@cip.ifi.lmu.de)
- * @version $Revision: 4791 $
+ * @version $Revision: 9434 $
  */
 public class OPTICS 
     extends AbstractClusterer 
@@ -146,9 +147,9 @@ public class OPTICS
 
     /**
      * Holds the distance-type that is used
-     * (default = weka.clusterers.forOPTICSAndDBScan.DataObjects.EuclidianDataObject)
+     * (default = weka.clusterers.forOPTICSAndDBScan.DataObjects.EuclideanDataObject)
      */
-    private String database_distanceType = "weka.clusterers.forOPTICSAndDBScan.DataObjects.EuclidianDataObject";
+    private String database_distanceType = "weka.clusterers.forOPTICSAndDBScan.DataObjects.EuclideanDataObject";
 
     /**
      * Holds the type of the used database
@@ -197,6 +198,8 @@ public class OPTICS
      */
     public Capabilities getCapabilities() {
       Capabilities result = super.getCapabilities();
+      result.disableAll();
+      result.enable(Capability.NO_CLASS);
 
       // attributes
       result.enable(Capability.NOMINAL_ATTRIBUTES);
@@ -417,7 +420,7 @@ public class OPTICS
         
         vector.addElement(
             new Option(
-        	"\tdistance-type (default = weka.clusterers.forOPTICSAndDBScan.DataObjects.EuclidianDataObject)",
+        	"\tdistance-type (default = weka.clusterers.forOPTICSAndDBScan.DataObjects.EuclideanDataObject)",
         	"D", 1, "-D <String>"));
         
         vector.addElement(
@@ -460,7 +463,7 @@ public class OPTICS
      *  index (database) used for OPTICS (default = weka.clusterers.forOPTICSAndDBScan.Databases.SequentialDatabase)</pre>
      * 
      * <pre> -D &lt;String&gt;
-     *  distance-type (default = weka.clusterers.forOPTICSAndDBScan.DataObjects.EuclidianDataObject)</pre>
+     *  distance-type (default = weka.clusterers.forOPTICSAndDBScan.DataObjects.EuclideanDataObject)</pre>
      * 
      * <pre> -F
      *  write results to OPTICS_#TimeStamp#.TXT - File</pre>
@@ -503,7 +506,7 @@ public class OPTICS
         if (optionString.length() != 0)
             setDatabase_distanceType(optionString);
         else
-            setDatabase_distanceType(weka.clusterers.forOPTICSAndDBScan.DataObjects.EuclidianDataObject.class.getName());
+            setDatabase_distanceType(weka.clusterers.forOPTICSAndDBScan.DataObjects.EuclideanDataObject.class.getName());
 
         setWriteOPTICSresults(Utils.getFlag('F', options));
 
@@ -815,7 +818,10 @@ public class OPTICS
      * @return String Information for the gui-explorer
      */
     public String globalInfo() {
-        return getTechnicalInformation().toString();
+        return "Basic implementation of OPTICS clustering algorithm that should "
+          + "*not* be used as a reference for runtime benchmarks: more sophisticated "
+          + "implementations exist! Clustering of new instances is not supported. More info:\n\n "
+          + getTechnicalInformation().toString();
     }
 
     /**
@@ -889,17 +895,18 @@ public class OPTICS
      * @return		the revision
      */
     public String getRevision() {
-      return RevisionUtils.extract("$Revision: 4791 $");
+      return RevisionUtils.extract("$Revision: 9434 $");
     }
 
     /**
      * Main Method for testing OPTICS
      * @param args Valid parameters are: 'E' epsilon (default = 0.9); 'M' minPoints (default = 6);
      *                                   'I' index-type (default = weka.clusterers.forOPTICSAndDBScan.Databases.SequentialDatabase);
-     *                                   'D' distance-type (default = weka.clusterers.forOPTICSAndDBScan.DataObjects.EuclidianDataObject);
+     *                                   'D' distance-type (default = weka.clusterers.forOPTICSAndDBScan.DataObjects.EuclideanDataObject);
      *                                   'F' write results to OPTICS_#TimeStamp#.TXT - File
      */
     public static void main(String[] args) {
         runClusterer(new OPTICS(), args);
     }
 }
+
