@@ -17,7 +17,7 @@ package weka.core;
  * @author wolfgang.hoschek@cern.ch
  * @author Eibe Frank (eibe@cs.waikato.ac.nz)
  * @author Richard Kirkby (rkirkby@cs.waikato.ac.nz)
- * @version $Revision: 1.10 $
+ * @version $Revision: 5619 $
  */
 public class Statistics
   implements RevisionHandler {
@@ -356,7 +356,7 @@ public class Statistics
    *
    * @param a the argument to the function.
    */
-  static double errorFunction(double x) { 
+  public static double errorFunction(double x) { 
     double y, z;
     final double T[] = {
       9.60497373987051638749E0,
@@ -405,7 +405,7 @@ public class Statistics
    *
    * @param a the argument to the function.
    */
-  static double errorFunctionComplemented(double a) { 
+  public static double errorFunctionComplemented(double a) { 
     double x,y,z,p,q;
   
     double P[] = {
@@ -506,7 +506,7 @@ public class Statistics
    * @param coef the coefficients of the polynomial.
    * @param N the degree of the polynomial.
    */
-  static double p1evl( double x, double coef[], int N ) {
+  public static double p1evl( double x, double coef[], int N ) {
   
     double ans;
     ans = x + coef[0];
@@ -549,7 +549,7 @@ public class Statistics
    * @param a the parameter of the gamma distribution.
    * @param x the integration end point.
    */
-  static double incompleteGamma(double a, double x) 
+  public static double incompleteGamma(double a, double x) 
     { 
  
     double ans, ax, c, r;
@@ -584,7 +584,7 @@ public class Statistics
    * @param a the parameter of the gamma distribution.
    * @param x the integration start point.
    */
-  static double incompleteGammaComplement( double a, double x ) {
+  public static double incompleteGammaComplement( double a, double x ) {
 
     double ans, ax, c, yc, r, t, y, z;
     double pk, pkm1, pkm2, qk, qkm1, qkm2;
@@ -640,7 +640,7 @@ public class Statistics
   /**
    * Returns the Gamma function of the argument.
    */
-  static double gamma(double x) {
+  public static double gamma(double x) {
 
     double P[] = {
       1.60119522476751861407E-4,
@@ -848,7 +848,7 @@ public class Statistics
   /**
    * Continued fraction expansion #1 for incomplete beta integral.
    */
-  static double incompleteBetaFraction1( double a, double b, double x ) {
+  public static double incompleteBetaFraction1( double a, double b, double x ) {
 
     double xk, pk, pkm1, pkm2, qk, qkm1, qkm2;
     double k1, k2, k3, k4, k5, k6, k7, k8;
@@ -927,7 +927,7 @@ public class Statistics
   /**
    * Continued fraction expansion #2 for incomplete beta integral.
    */
-  static double incompleteBetaFraction2( double a, double b, double x ) {
+  public static double incompleteBetaFraction2( double a, double b, double x ) {
 
     double xk, pk, pkm1, pkm2, qk, qkm1, qkm2;
     double k1, k2, k3, k4, k5, k6, k7, k8;
@@ -1048,7 +1048,7 @@ public class Statistics
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 1.10 $");
+    return RevisionUtils.extract("$Revision: 5619 $");
   }
 
   /**
