@@ -57,7 +57,7 @@ import weka.core.Utils;
  * <p>
  * 
  * @author Len Trigg (trigg@cs.waikato.ac.nz)
- * @version $Revision: 10206 $
+ * @version $Revision: 11887 $
  */
 public class DatabaseUtils implements Serializable, RevisionHandler {
 
@@ -114,6 +114,8 @@ public class DatabaseUtils implements Serializable, RevisionHandler {
   public static final int TEXT = 9;
   /** Type mapping for TIME used for reading TIME columns. */
   public static final int TIME = 10;
+  /** Type mapping for TIMESTAMP used for reading java.sql.Timestamp columns */
+  public static final int TIMESTAMP = 11;
 
   /** Database URL. */
   protected String m_DatabaseURL;
@@ -1375,6 +1377,6 @@ public class DatabaseUtils implements Serializable, RevisionHandler {
    */
   @Override
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 10206 $");
+    return RevisionUtils.extract("$Revision: 11887 $");
   }
 }
