@@ -31,6 +31,7 @@ import weka.core.OptionHandler;
 import weka.core.Queue;
 import weka.core.RelationalLocator;
 import weka.core.RevisionHandler;
+import weka.core.RevisionUtils;
 import weka.core.SerializedObject;
 import weka.core.StringLocator;
 import weka.core.UnsupportedAttributeTypeException;
@@ -74,7 +75,7 @@ import java.util.Iterator;
  * </pre> </code>
  *
  * @author Len Trigg (trigg@cs.waikato.ac.nz)
- * @version $Revision: 1.42 $
+ * @version $Revision: 7880 $
  */
 public abstract class Filter
   implements Serializable, CapabilitiesHandler, RevisionHandler {
@@ -145,10 +146,21 @@ public abstract class Filter
     Capabilities 	result;
 
     result = new Capabilities(this);
+    result.enableAll();
+    
     result.setMinimumNumberInstances(0);
     
     return result;
   }
+  
+  /**
+   * Returns the revision string.
+   * 
+   * @return            the revision
+   */
+  public String getRevision() {
+    return RevisionUtils.extract("$Revision: 7880 $");
+  }
 
   /** 
    * Returns the Capabilities of this filter, customized based on the data.
@@ -404,6 +416,8 @@ public abstract class Filter
     if (    (m_InputStringAtts.getAttributeIndices().length > 0) 
 	 || (m_InputRelAtts.getAttributeIndices().length > 0) ) {
       m_InputFormat = m_InputFormat.stringFreeStructure();
+      m_InputStringAtts = new StringLocator(m_InputFormat, m_InputStringAtts.getAllowedIndices());
+      m_InputRelAtts = new RelationalLocator(m_InputFormat, m_InputRelAtts.getAllowedIndices());
     } else {
       // This more efficient than new Instances(m_InputFormat, 0);
       m_InputFormat.delete();
@@ -517,6 +531,16 @@ public abstract class Filter
     flushInput();
     m_NewBatch = true;
     m_FirstBatchDone = true;
+    
+    if (m_OutputQueue.empty()) {
+      // Clear out references to old strings/relationals occasionally
+      if (    (m_OutputStringAtts.getAttributeIndices().length > 0)
+          || (m_OutputRelAtts.getAttributeIndices().length > 0) ) {
+        m_OutputFormat = m_OutputFormat.stringFreeStructure();
+        m_OutputStringAtts = new StringLocator(m_OutputFormat, m_OutputStringAtts.getAllowedIndices());
+      }
+    }
+    
     return (numPendingOutput() != 0);
   }
 
@@ -537,13 +561,7 @@ public abstract class Filter
       return null;
     }
     Instance result = (Instance)m_OutputQueue.pop();
-    // Clear out references to old strings/relationals occasionally
-    if (m_OutputQueue.empty() && m_NewBatch) {
-      if (    (m_OutputStringAtts.getAttributeIndices().length > 0)
-	   || (m_OutputRelAtts.getAttributeIndices().length > 0) ) {
-        m_OutputFormat = m_OutputFormat.stringFreeStructure();
-      }
-    }
+
     return result;
   }
   
