@@ -23,22 +23,6 @@
 
 package weka.filters.supervised.instance;
 
-import weka.core.Attribute;
-import weka.core.Capabilities;
-import weka.core.Instance;
-import weka.core.Instances;
-import weka.core.Option;
-import weka.core.OptionHandler;
-import weka.core.RevisionUtils;
-import weka.core.TechnicalInformation;
-import weka.core.TechnicalInformationHandler;
-import weka.core.Utils;
-import weka.core.Capabilities.Capability;
-import weka.core.TechnicalInformation.Field;
-import weka.core.TechnicalInformation.Type;
-import weka.filters.Filter;
-import weka.filters.SupervisedFilter;
-
 import java.util.Collections;
 import java.util.Comparator;
 import java.util.Enumeration;
@@ -52,16 +36,35 @@ import java.util.Random;
 import java.util.Set;
 import java.util.Vector;
 
+import weka.core.Attribute;
+import weka.core.Capabilities;
+import weka.core.Capabilities.Capability;
+import weka.core.Instance;
+import weka.core.Instances;
+import weka.core.Option;
+import weka.core.OptionHandler;
+import weka.core.RevisionUtils;
+import weka.core.TechnicalInformation;
+import weka.core.TechnicalInformation.Field;
+import weka.core.TechnicalInformation.Type;
+import weka.core.TechnicalInformationHandler;
+import weka.core.Utils;
+import weka.filters.Filter;
+import weka.filters.SupervisedFilter;
+
 /**
- <!-- globalinfo-start -->
- * Resamples a dataset by applying the Synthetic Minority Oversampling TEchnique (SMOTE). The original dataset must fit entirely in memory. The amount of SMOTE and number of nearest neighbors may be specified. For more information, see <br/>
+ * <!-- globalinfo-start --> Resamples a dataset by applying the Synthetic
+ * Minority Oversampling TEchnique (SMOTE). The original dataset must fit
+ * entirely in memory. The amount of SMOTE and number of nearest neighbors may
+ * be specified. For more information, see <br/>
  * <br/>
- * Nitesh V. Chawla et. al. (2002). Synthetic Minority Over-sampling Technique. Journal of Artificial Intelligence Research. 16:321-357.
+ * Nitesh V. Chawla et. al. (2002). Synthetic Minority Over-sampling Technique.
+ * Journal of Artificial Intelligence Research. 16:321-357.
  * <p/>
- <!-- globalinfo-end -->
- *
- <!-- technical-bibtex-start -->
- * BibTeX:
+ * <!-- globalinfo-end -->
+ * 
+ * <!-- technical-bibtex-start --> BibTeX:
+ * 
  * <pre>
  * &#64;article{al.2002,
  *    author = {Nitesh V. Chawla et. al.},
@@ -73,84 +76,89 @@ import java.util.Vector;
  * }
  * </pre>
  * <p/>
- <!-- technical-bibtex-end -->
+ * <!-- technical-bibtex-end -->
  * 
- <!-- options-start -->
- * Valid options are: <p/>
+ * <!-- options-start --> Valid options are:
+ * <p/>
  * 
- * <pre> -S &lt;num&gt;
+ * <pre>
+ * -S &lt;num&gt;
  *  Specifies the random number seed
- *  (default 1)</pre>
+ *  (default 1)
+ * </pre>
  * 
- * <pre> -P &lt;percentage&gt;
+ * <pre>
+ * -P &lt;percentage&gt;
  *  Specifies percentage of SMOTE instances to create.
  *  (default 100.0)
  * </pre>
  * 
- * <pre> -K &lt;nearest-neighbors&gt;
+ * <pre>
+ * -K &lt;nearest-neighbors&gt;
  *  Specifies the number of nearest neighbors to use.
  *  (default 5)
  * </pre>
  * 
- * <pre> -C &lt;value-index&gt;
+ * <pre>
+ * -C &lt;value-index&gt;
  *  Specifies the index of the nominal class value to SMOTE
  *  (default 0: auto-detect non-empty minority class))
  * </pre>
  * 
- <!-- options-end -->
- *  
+ * <!-- options-end -->
+ * 
  * @author Ryan Lichtenwalter (rlichtenwalter@gmail.com)
- * @version $Revision: 5542 $
+ * @version $Revision: 9657 $
  */
-public class SMOTE
-  extends Filter 
-  implements SupervisedFilter, OptionHandler, TechnicalInformationHandler {
+public class SMOTE extends Filter implements SupervisedFilter, OptionHandler,
+    TechnicalInformationHandler {
 
   /** for serialization. */
   static final long serialVersionUID = -1653880819059250364L;
 
   /** the number of neighbors to use. */
   protected int m_NearestNeighbors = 5;
-  
+
   /** the random seed to use. */
   protected int m_RandomSeed = 1;
-  
+
   /** the percentage of SMOTE instances to create. */
   protected double m_Percentage = 100.0;
-  
+
   /** the index of the class value. */
   protected String m_ClassValueIndex = "0";
-  
+
   /** whether to detect the minority class automatically. */
   protected boolean m_DetectMinorityClass = true;
 
   /**
    * Returns a string describing this classifier.
    * 
-   * @return 		a description of the classifier suitable for
-   * 			displaying in the explorer/experimenter gui
+   * @return a description of the classifier suitable for displaying in the
+   *         explorer/experimenter gui
    */
   public String globalInfo() {
-    return "Resamples a dataset by applying the Synthetic Minority Oversampling TEchnique (SMOTE)." +
-    " The original dataset must fit entirely in memory." +
-    " The amount of SMOTE and number of nearest neighbors may be specified." +
-    " For more information, see \n\n" 
-    + getTechnicalInformation().toString();
+    return "Resamples a dataset by applying the Synthetic Minority Oversampling TEchnique (SMOTE)."
+        + " The original dataset must fit entirely in memory."
+        + " The amount of SMOTE and number of nearest neighbors may be specified."
+        + " For more information, see \n\n"
+        + getTechnicalInformation().toString();
   }
 
   /**
-   * Returns an instance of a TechnicalInformation object, containing 
-   * detailed information about the technical background of this class,
-   * e.g., paper reference or book this class is based on.
+   * Returns an instance of a TechnicalInformation object, containing detailed
+   * information about the technical background of this class, e.g., paper
+   * reference or book this class is based on.
    * 
-   * @return 		the technical information about this class
+   * @return the technical information about this class
    */
   public TechnicalInformation getTechnicalInformation() {
     TechnicalInformation result = new TechnicalInformation(Type.ARTICLE);
 
     result.setValue(Field.AUTHOR, "Nitesh V. Chawla et. al.");
     result.setValue(Field.TITLE, "Synthetic Minority Over-sampling Technique");
-    result.setValue(Field.JOURNAL, "Journal of Artificial Intelligence Research");
+    result.setValue(Field.JOURNAL,
+        "Journal of Artificial Intelligence Research");
     result.setValue(Field.YEAR, "2002");
     result.setValue(Field.VOLUME, "16");
     result.setValue(Field.PAGES, "321-357");
@@ -161,18 +169,20 @@ public class SMOTE
   /**
    * Returns the revision string.
    * 
-   * @return 		the revision
+   * @return the revision
    */
+  @Override
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 5542 $");
+    return RevisionUtils.extract("$Revision: 9657 $");
   }
 
-  /** 
+  /**
    * Returns the Capabilities of this filter.
-   *
-   * @return            the capabilities of this object
-   * @see               Capabilities
+   * 
+   * @return the capabilities of this object
+   * @see Capabilities
    */
+  @Override
   public Capabilities getCapabilities() {
     Capabilities result = super.getCapabilities();
     result.disableAll();
@@ -190,31 +200,27 @@ public class SMOTE
 
   /**
    * Returns an enumeration describing the available options.
-   *
+   * 
    * @return an enumeration of all the available options.
    */
   public Enumeration listOptions() {
     Vector newVector = new Vector();
-    
+
+    newVector.addElement(new Option("\tSpecifies the random number seed\n"
+        + "\t(default 1)", "S", 1, "-S <num>"));
+
     newVector.addElement(new Option(
-	"\tSpecifies the random number seed\n"
-	+ "\t(default 1)",
-	"S", 1, "-S <num>"));
-    
+        "\tSpecifies percentage of SMOTE instances to create.\n"
+            + "\t(default 100.0)\n", "P", 1, "-P <percentage>"));
+
     newVector.addElement(new Option(
-	"\tSpecifies percentage of SMOTE instances to create.\n"
-	+ "\t(default 100.0)\n",
-	"P", 1, "-P <percentage>"));
-    
+        "\tSpecifies the number of nearest neighbors to use.\n"
+            + "\t(default 5)\n", "K", 1, "-K <nearest-neighbors>"));
+
     newVector.addElement(new Option(
-	"\tSpecifies the number of nearest neighbors to use.\n"
-	+ "\t(default 5)\n",
-	"K", 1, "-K <nearest-neighbors>"));
-    
-    newVector.addElement(new Option(
-	"\tSpecifies the index of the nominal class value to SMOTE\n"
-	+"\t(default 0: auto-detect non-empty minority class))\n",
-	"C", 1, "-C <value-index>"));
+        "\tSpecifies the index of the nominal class value to SMOTE\n"
+            + "\t(default 0: auto-detect non-empty minority class))\n", "C", 1,
+        "-C <value-index>"));
 
     return newVector.elements();
   }
@@ -222,30 +228,35 @@ public class SMOTE
   /**
    * Parses a given list of options.
    * 
-   <!-- options-start -->
-   * Valid options are: <p/>
+   * <!-- options-start --> Valid options are:
+   * <p/>
    * 
-   * <pre> -S &lt;num&gt;
+   * <pre>
+   * -S &lt;num&gt;
    *  Specifies the random number seed
-   *  (default 1)</pre>
+   *  (default 1)
+   * </pre>
    * 
-   * <pre> -P &lt;percentage&gt;
+   * <pre>
+   * -P &lt;percentage&gt;
    *  Specifies percentage of SMOTE instances to create.
    *  (default 100.0)
    * </pre>
    * 
-   * <pre> -K &lt;nearest-neighbors&gt;
+   * <pre>
+   * -K &lt;nearest-neighbors&gt;
    *  Specifies the number of nearest neighbors to use.
    *  (default 5)
    * </pre>
    * 
-   * <pre> -C &lt;value-index&gt;
+   * <pre>
+   * -C &lt;value-index&gt;
    *  Specifies the index of the nominal class value to SMOTE
    *  (default 0: auto-detect non-empty minority class))
    * </pre>
    * 
-   <!-- options-end -->
-   *
+   * <!-- options-end -->
+   * 
    * @param options the list of options as an array of strings
    * @throws Exception if an option is not supported
    */
@@ -271,7 +282,7 @@ public class SMOTE
       setNearestNeighbors(5);
     }
 
-    String classValueIndexStr = Utils.getOption( 'C', options);
+    String classValueIndexStr = Utils.getOption('C', options);
     if (classValueIndexStr.length() != 0) {
       setClassValue(classValueIndexStr);
     } else {
@@ -281,34 +292,34 @@ public class SMOTE
 
   /**
    * Gets the current settings of the filter.
-   *
-   * @return an array 	of strings suitable for passing to setOptions
+   * 
+   * @return an array of strings suitable for passing to setOptions
    */
   public String[] getOptions() {
-    Vector<String>	result;
-    
+    Vector<String> result;
+
     result = new Vector<String>();
-    
+
     result.add("-C");
     result.add(getClassValue());
-    
+
     result.add("-K");
     result.add("" + getNearestNeighbors());
-    
+
     result.add("-P");
     result.add("" + getPercentage());
-    
+
     result.add("-S");
     result.add("" + getRandomSeed());
-    
+
     return result.toArray(new String[result.size()]);
   }
 
   /**
    * Returns the tip text for this property.
    * 
-   * @return 		tip text for this property suitable for
-   * 			displaying in the explorer/experimenter gui
+   * @return tip text for this property suitable for displaying in the
+   *         explorer/experimenter gui
    */
   public String randomSeedTipText() {
     return "The seed used for random sampling.";
@@ -316,8 +327,8 @@ public class SMOTE
 
   /**
    * Gets the random number seed.
-   *
-   * @return 		the random number seed.
+   * 
+   * @return the random number seed.
    */
   public int getRandomSeed() {
     return m_RandomSeed;
@@ -325,8 +336,8 @@ public class SMOTE
 
   /**
    * Sets the random number seed.
-   *
-   * @param value 	the new random number seed.
+   * 
+   * @param value the new random number seed.
    */
   public void setRandomSeed(int value) {
     m_RandomSeed = value;
@@ -335,8 +346,8 @@ public class SMOTE
   /**
    * Returns the tip text for this property.
    * 
-   * @return 		tip text for this property suitable for
-   * 			displaying in the explorer/experimenter gui
+   * @return tip text for this property suitable for displaying in the
+   *         explorer/experimenter gui
    */
   public String percentageTipText() {
     return "The percentage of SMOTE instances to create.";
@@ -345,7 +356,7 @@ public class SMOTE
   /**
    * Sets the percentage of SMOTE instances to create.
    * 
-   * @param value	the percentage to use
+   * @param value the percentage to use
    */
   public void setPercentage(double value) {
     if (value >= 0)
@@ -357,7 +368,7 @@ public class SMOTE
   /**
    * Gets the percentage of SMOTE instances to create.
    * 
-   * @return 		the percentage of SMOTE instances to create
+   * @return the percentage of SMOTE instances to create
    */
   public double getPercentage() {
     return m_Percentage;
@@ -366,8 +377,8 @@ public class SMOTE
   /**
    * Returns the tip text for this property.
    * 
-   * @return 		tip text for this property suitable for
-   * 			displaying in the explorer/experimenter gui
+   * @return tip text for this property suitable for displaying in the
+   *         explorer/experimenter gui
    */
   public String nearestNeighborsTipText() {
     return "The number of nearest neighbors to use.";
@@ -376,7 +387,7 @@ public class SMOTE
   /**
    * Sets the number of nearest neighbors to use.
    * 
-   * @param value	the number of nearest neighbors to use
+   * @param value the number of nearest neighbors to use
    */
   public void setNearestNeighbors(int value) {
     if (value >= 1)
@@ -388,7 +399,7 @@ public class SMOTE
   /**
    * Gets the number of nearest neighbors to use.
    * 
-   * @return 		the number of nearest neighbors to use
+   * @return the number of nearest neighbors to use
    */
   public int getNearestNeighbors() {
     return m_NearestNeighbors;
@@ -397,18 +408,18 @@ public class SMOTE
   /**
    * Returns the tip text for this property.
    * 
-   * @return 		tip text for this property suitable for
-   * 			displaying in the explorer/experimenter gui
+   * @return tip text for this property suitable for displaying in the
+   *         explorer/experimenter gui
    */
   public String classValueTipText() {
-    return "The index of the class value to which SMOTE should be applied. " +
-    "Use a value of 0 to auto-detect the non-empty minority class.";
+    return "The index of the class value to which SMOTE should be applied. "
+        + "Use a value of 0 to auto-detect the non-empty minority class.";
   }
 
   /**
    * Sets the index of the class value to which SMOTE should be applied.
    * 
-   * @param value	the class value index
+   * @param value the class value index
    */
   public void setClassValue(String value) {
     m_ClassValueIndex = value;
@@ -422,7 +433,7 @@ public class SMOTE
   /**
    * Gets the index of the class value to which SMOTE should be applied.
    * 
-   * @return 		the index of the clas value to which SMOTE should be applied
+   * @return the index of the clas value to which SMOTE should be applied
    */
   public String getClassValue() {
     return m_ClassValueIndex;
@@ -430,13 +441,14 @@ public class SMOTE
 
   /**
    * Sets the format of the input instances.
-   *
-   * @param instanceInfo 	an Instances object containing the input 
-   * 				instance structure (any instances contained in 
-   * 				the object are ignored - only the structure is required).
-   * @return 			true if the outputFormat may be collected immediately
-   * @throws Exception 		if the input format can't be set successfully
+   * 
+   * @param instanceInfo an Instances object containing the input instance
+   *          structure (any instances contained in the object are ignored -
+   *          only the structure is required).
+   * @return true if the outputFormat may be collected immediately
+   * @throws Exception if the input format can't be set successfully
    */
+  @Override
   public boolean setInputFormat(Instances instanceInfo) throws Exception {
     super.setInputFormat(instanceInfo);
     super.setOutputFormat(instanceInfo);
@@ -444,14 +456,14 @@ public class SMOTE
   }
 
   /**
-   * Input an instance for filtering. Filter requires all
-   * training instances be read before producing output.
-   *
-   * @param instance 		the input instance
-   * @return 			true if the filtered instance may now be
-   * 				collected with output().
+   * Input an instance for filtering. Filter requires all training instances be
+   * read before producing output.
+   * 
+   * @param instance the input instance
+   * @return true if the filtered instance may now be collected with output().
    * @throws IllegalStateException if no input structure has been defined
    */
+  @Override
   public boolean input(Instance instance) {
     if (getInputFormat() == null) {
       throw new IllegalStateException("No input instance format defined");
@@ -470,15 +482,15 @@ public class SMOTE
   }
 
   /**
-   * Signify that this batch of input to the filter is finished. 
-   * If the filter requires all instances prior to filtering,
-   * output() may now be called to retrieve the filtered instances.
-   *
-   * @return 		true if there are instances pending output
+   * Signify that this batch of input to the filter is finished. If the filter
+   * requires all instances prior to filtering, output() may now be called to
+   * retrieve the filtered instances.
+   * 
+   * @return true if there are instances pending output
    * @throws IllegalStateException if no input structure has been defined
-   * @throws Exception 	if provided options cannot be executed 
-   * 			on input instances
+   * @throws Exception if provided options cannot be executed on input instances
    */
+  @Override
   public boolean batchFinished() throws Exception {
     if (getInputFormat() == null) {
       throw new IllegalStateException("No input instance format defined");
@@ -496,35 +508,35 @@ public class SMOTE
   }
 
   /**
-   * The procedure implementing the SMOTE algorithm. The output
-   * instances are pushed onto the output queue for collection.
+   * The procedure implementing the SMOTE algorithm. The output instances are
+   * pushed onto the output queue for collection.
    * 
-   * @throws Exception 	if provided options cannot be executed 
-   * 			on input instances
+   * @throws Exception if provided options cannot be executed on input instances
    */
   protected void doSMOTE() throws Exception {
     int minIndex = 0;
     int min = Integer.MAX_VALUE;
     if (m_DetectMinorityClass) {
       // find minority class
-      int[] classCounts = getInputFormat().attributeStats(getInputFormat().classIndex()).nominalCounts;
+      int[] classCounts = getInputFormat().attributeStats(
+          getInputFormat().classIndex()).nominalCounts;
       for (int i = 0; i < classCounts.length; i++) {
-	if (classCounts[i] != 0 && classCounts[i] < min) {
-	  min = classCounts[i];
-	  minIndex = i;
-	}
+        if (classCounts[i] != 0 && classCounts[i] < min) {
+          min = classCounts[i];
+          minIndex = i;
+        }
       }
     } else {
       String classVal = getClassValue();
       if (classVal.equalsIgnoreCase("first")) {
-	minIndex = 1;
+        minIndex = 1;
       } else if (classVal.equalsIgnoreCase("last")) {
-	minIndex = getInputFormat().numClasses();
+        minIndex = getInputFormat().numClasses();
       } else {
-	minIndex = Integer.parseInt(classVal);
+        minIndex = Integer.parseInt(classVal);
       }
       if (minIndex > getInputFormat().numClasses()) {
-	throw new Exception("value index must be <= the number of classes");
+        throw new Exception("value index must be <= the number of classes");
       }
       minIndex--; // make it an index
     }
@@ -542,62 +554,66 @@ public class SMOTE
     // also push all dataset instances
     Instances sample = getInputFormat().stringFreeStructure();
     Enumeration instanceEnum = getInputFormat().enumerateInstances();
-    while(instanceEnum.hasMoreElements()) {
+    while (instanceEnum.hasMoreElements()) {
       Instance instance = (Instance) instanceEnum.nextElement();
       push((Instance) instance.copy());
       if ((int) instance.classValue() == minIndex) {
-	sample.add(instance);
+        sample.add(instance);
       }
     }
 
     // compute Value Distance Metric matrices for nominal features
     Map vdmMap = new HashMap();
     Enumeration attrEnum = getInputFormat().enumerateAttributes();
-    while(attrEnum.hasMoreElements()) {
+    while (attrEnum.hasMoreElements()) {
       Attribute attr = (Attribute) attrEnum.nextElement();
       if (!attr.equals(getInputFormat().classAttribute())) {
-	if (attr.isNominal() || attr.isString()) {
-	  double[][] vdm = new double[attr.numValues()][attr.numValues()];
-	  vdmMap.put(attr, vdm);
-	  int[] featureValueCounts = new int[attr.numValues()];
-	  int[][] featureValueCountsByClass = new int[getInputFormat().classAttribute().numValues()][attr.numValues()];
-	  instanceEnum = getInputFormat().enumerateInstances();
-	  while(instanceEnum.hasMoreElements()) {
-	    Instance instance = (Instance) instanceEnum.nextElement();
-	    int value = (int) instance.value(attr);
-	    int classValue = (int) instance.classValue();
-	    featureValueCounts[value]++;
-	    featureValueCountsByClass[classValue][value]++;
-	  }
-	  for (int valueIndex1 = 0; valueIndex1 < attr.numValues(); valueIndex1++) {
-	    for (int valueIndex2 = 0; valueIndex2 < attr.numValues(); valueIndex2++) {
-	      double sum = 0;
-	      for (int classValueIndex = 0; classValueIndex < getInputFormat().numClasses(); classValueIndex++) {
-		double c1i = (double) featureValueCountsByClass[classValueIndex][valueIndex1];
-		double c2i = (double) featureValueCountsByClass[classValueIndex][valueIndex2];
-		double c1 = (double) featureValueCounts[valueIndex1];
-		double c2 = (double) featureValueCounts[valueIndex2];
-		double term1 = c1i / c1;
-		double term2 = c2i / c2;
-		sum += Math.abs(term1 - term2);
-	      }
-	      vdm[valueIndex1][valueIndex2] = sum;
-	    }
-	  }
-	}
+        if (attr.isNominal() || attr.isString()) {
+          double[][] vdm = new double[attr.numValues()][attr.numValues()];
+          vdmMap.put(attr, vdm);
+          int[] featureValueCounts = new int[attr.numValues()];
+          int[][] featureValueCountsByClass = new int[getInputFormat()
+              .classAttribute().numValues()][attr.numValues()];
+          instanceEnum = getInputFormat().enumerateInstances();
+          while (instanceEnum.hasMoreElements()) {
+            Instance instance = (Instance) instanceEnum.nextElement();
+            int value = (int) instance.value(attr);
+            int classValue = (int) instance.classValue();
+            featureValueCounts[value]++;
+            featureValueCountsByClass[classValue][value]++;
+          }
+          for (int valueIndex1 = 0; valueIndex1 < attr.numValues(); valueIndex1++) {
+            for (int valueIndex2 = 0; valueIndex2 < attr.numValues(); valueIndex2++) {
+              double sum = 0;
+              for (int classValueIndex = 0; classValueIndex < getInputFormat()
+                  .numClasses(); classValueIndex++) {
+                double c1i = featureValueCountsByClass[classValueIndex][valueIndex1];
+                double c2i = featureValueCountsByClass[classValueIndex][valueIndex2];
+                double c1 = featureValueCounts[valueIndex1];
+                double c2 = featureValueCounts[valueIndex2];
+                double term1 = c1i / c1;
+                double term2 = c2i / c2;
+                sum += Math.abs(term1 - term2);
+              }
+              vdm[valueIndex1][valueIndex2] = sum;
+            }
+          }
+        }
       }
     }
 
     // use this random source for all required randomness
     Random rand = new Random(getRandomSeed());
 
-    // find the set of extra indices to use if the percentage is not evenly divisible by 100
+    // find the set of extra indices to use if the percentage is not evenly
+    // divisible by 100
     List extraIndices = new LinkedList();
-    double percentageRemainder = (getPercentage() / 100) - Math.floor(getPercentage() / 100.0);
+    double percentageRemainder = (getPercentage() / 100)
+        - Math.floor(getPercentage() / 100.0);
     int extraIndicesCount = (int) (percentageRemainder * sample.numInstances());
     if (extraIndicesCount >= 1) {
       for (int i = 0; i < sample.numInstances(); i++) {
-	extraIndices.add(i);
+        extraIndices.add(i);
       }
     }
     Collections.shuffle(extraIndices, rand);
@@ -612,94 +628,93 @@ public class SMOTE
       // find k nearest neighbors for each instance
       List distanceToInstance = new LinkedList();
       for (int j = 0; j < sample.numInstances(); j++) {
-	Instance instanceJ = sample.instance(j);
-	if (i != j) {
-	  double distance = 0;
-	  attrEnum = getInputFormat().enumerateAttributes();
-	  while(attrEnum.hasMoreElements()) {
-	    Attribute attr = (Attribute) attrEnum.nextElement();
-	    if (!attr.equals(getInputFormat().classAttribute())) {
-	      double iVal = instanceI.value(attr);
-	      double jVal = instanceJ.value(attr);
-	      if (attr.isNumeric()) {
-		distance += Math.pow(iVal - jVal, 2);
-	      } else {
-		distance += ((double[][]) vdmMap.get(attr))[(int) iVal][(int) jVal];
-	      }
-	    }
-	  }
-	  distance = Math.pow(distance, .5);
-	  distanceToInstance.add(new Object[] {distance, instanceJ});
-	}
+        Instance instanceJ = sample.instance(j);
+        if (i != j) {
+          double distance = 0;
+          attrEnum = getInputFormat().enumerateAttributes();
+          while (attrEnum.hasMoreElements()) {
+            Attribute attr = (Attribute) attrEnum.nextElement();
+            if (!attr.equals(getInputFormat().classAttribute())) {
+              double iVal = instanceI.value(attr);
+              double jVal = instanceJ.value(attr);
+              if (attr.isNumeric()) {
+                distance += Math.pow(iVal - jVal, 2);
+              } else {
+                distance += ((double[][]) vdmMap.get(attr))[(int) iVal][(int) jVal];
+              }
+            }
+          }
+          distance = Math.pow(distance, .5);
+          distanceToInstance.add(new Object[] { distance, instanceJ });
+        }
       }
 
       // sort the neighbors according to distance
       Collections.sort(distanceToInstance, new Comparator() {
-	public int compare(Object o1, Object o2) {
-	  double distance1 = (Double) ((Object[]) o1)[0];
-	  double distance2 = (Double) ((Object[]) o2)[0];
-	  return (int) Math.ceil(distance1 - distance2);
-	}
+        public int compare(Object o1, Object o2) {
+          double distance1 = (Double) ((Object[]) o1)[0];
+          double distance2 = (Double) ((Object[]) o2)[0];
+          return Double.compare(distance1, distance2);
+        }
       });
 
       // populate the actual nearest neighbor instance array
       Iterator entryIterator = distanceToInstance.iterator();
       int j = 0;
-      while(entryIterator.hasNext() && j < nearestNeighbors) {
-	nnArray[j] = (Instance) ((Object[])entryIterator.next())[1];
-	j++;
+      while (entryIterator.hasNext() && j < nearestNeighbors) {
+        nnArray[j] = (Instance) ((Object[]) entryIterator.next())[1];
+        j++;
       }
 
       // create synthetic examples
       int n = (int) Math.floor(getPercentage() / 100);
-      while(n > 0 || extraIndexSet.remove(i)) {
-	double[] values = new double[sample.numAttributes()];
-	int nn = rand.nextInt(nearestNeighbors);
-	attrEnum = getInputFormat().enumerateAttributes();
-	while(attrEnum.hasMoreElements()) {
-	  Attribute attr = (Attribute) attrEnum.nextElement();
-	  if (!attr.equals(getInputFormat().classAttribute())) {
-	    if (attr.isNumeric()) {
-	      double dif = nnArray[nn].value(attr) - instanceI.value(attr);
-	      double gap = rand.nextDouble();
-	      values[attr.index()] = (double) (instanceI.value(attr) + gap * dif);
-	    } else if (attr.isDate()) {
-	      double dif = nnArray[nn].value(attr) - instanceI.value(attr);
-	      double gap = rand.nextDouble();
-	      values[attr.index()] = (long) (instanceI.value(attr) + gap * dif);
-	    } else {
-	      int[] valueCounts = new int[attr.numValues()];
-	      int iVal = (int) instanceI.value(attr);
-	      valueCounts[iVal]++;
-	      for (int nnEx = 0; nnEx < nearestNeighbors; nnEx++) {
-		int val = (int) nnArray[nnEx].value(attr);
-		valueCounts[val]++;
-	      }
-	      int maxIndex = 0;
-	      int max = Integer.MIN_VALUE;
-	      for (int index = 0; index < attr.numValues(); index++) {
-		if (valueCounts[index] > max) {
-		  max = valueCounts[index];
-		  maxIndex = index;
-		}
-	      }
-	      values[attr.index()] = maxIndex;
-	    }
-	  }
-	}
-	values[sample.classIndex()] = minIndex;
-	Instance synthetic = new Instance(1.0, values);
-	push(synthetic);
-	n--;
+      while (n > 0 || extraIndexSet.remove(i)) {
+        double[] values = new double[sample.numAttributes()];
+        int nn = rand.nextInt(nearestNeighbors);
+        attrEnum = getInputFormat().enumerateAttributes();
+        while (attrEnum.hasMoreElements()) {
+          Attribute attr = (Attribute) attrEnum.nextElement();
+          if (!attr.equals(getInputFormat().classAttribute())) {
+            if (attr.isNumeric()) {
+              double dif = nnArray[nn].value(attr) - instanceI.value(attr);
+              double gap = rand.nextDouble();
+              values[attr.index()] = (instanceI.value(attr) + gap * dif);
+            } else if (attr.isDate()) {
+              double dif = nnArray[nn].value(attr) - instanceI.value(attr);
+              double gap = rand.nextDouble();
+              values[attr.index()] = (long) (instanceI.value(attr) + gap * dif);
+            } else {
+              int[] valueCounts = new int[attr.numValues()];
+              int iVal = (int) instanceI.value(attr);
+              valueCounts[iVal]++;
+              for (int nnEx = 0; nnEx < nearestNeighbors; nnEx++) {
+                int val = (int) nnArray[nnEx].value(attr);
+                valueCounts[val]++;
+              }
+              int maxIndex = 0;
+              int max = Integer.MIN_VALUE;
+              for (int index = 0; index < attr.numValues(); index++) {
+                if (valueCounts[index] > max) {
+                  max = valueCounts[index];
+                  maxIndex = index;
+                }
+              }
+              values[attr.index()] = maxIndex;
+            }
+          }
+        }
+        values[sample.classIndex()] = minIndex;
+        Instance synthetic = new Instance(1.0, values);
+        push(synthetic);
+        n--;
       }
     }
   }
 
   /**
    * Main method for running this filter.
-   *
-   * @param args 	should contain arguments to the filter: 
-   * 			use -h for help
+   * 
+   * @param args should contain arguments to the filter: use -h for help
    */
   public static void main(String[] args) {
     runFilter(new SMOTE(), args);
