@@ -35,8 +35,8 @@ import weka.core.Utils;
 import weka.core.Capabilities.Capability;
 import weka.core.mathematicalexpression.Parser;
 import weka.core.mathematicalexpression.Scanner;
-import weka.core.parser.java_cup.runtime.DefaultSymbolFactory;
-import weka.core.parser.java_cup.runtime.SymbolFactory;
+import java_cup.runtime.DefaultSymbolFactory;
+import java_cup.runtime.SymbolFactory;
 import weka.filters.UnsupervisedFilter;
 
 import java.io.ByteArrayInputStream;
@@ -75,7 +75,7 @@ import java.util.Vector;
  *
  * @author Eibe Frank (eibe@cs.waikato.ac.nz) 
  * @author Prados Julien (julien.prados@cui.unige.ch) 
- * @version $Revision: 1.10 $
+ * @version $Revision: 5543 $
  * @see MathematicalExpression
  */
 public class MathExpression 
@@ -124,6 +124,7 @@ public class MathExpression
    */
   public Capabilities getCapabilities() {
     Capabilities result = super.getCapabilities();
+    result.disableAll();
 
     // attributes
     result.enableAllAttributes();
@@ -264,9 +265,9 @@ public class MathExpression
       int[] newIndices = new int[instance.numAttributes()];
       double[] vals = instance.toDoubleArray();
       int ind = 0;
+      double value;
       for (int j = 0; j < instance.numAttributes(); j++) {
         if (m_SelectCols.isInRange(j)) {          
-	  double value;
 	  if (instance.attribute(j).isNumeric() &&
 	    (!Instance.isMissingValue(vals[j])) &&
 	    (getInputFormat().classIndex() != j)) {
@@ -288,14 +289,15 @@ public class MathExpression
 	        newIndices[ind] = j;
 	        ind++;
 	      }
-	  } else {
-	      value = vals[j];
-	      if (value != 0.0) {
-	        newVals[ind] = value;
-	        newIndices[ind] = j;
-	        ind++;
-	      }
+	      
 	  }
+        } else {
+          value = vals[j];
+          if (value != 0.0) {
+            newVals[ind] = value;
+            newIndices[ind] = j;
+            ind++;
+          }
         }
       }	
       double[] tempVals = new double[ind];
@@ -551,7 +553,7 @@ public class MathExpression
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 1.10 $");
+    return RevisionUtils.extract("$Revision: 5543 $");
   }
   
   /**
