@@ -91,7 +91,7 @@ import java.util.Vector;
  <!-- options-end -->
  *
  * @author  fracpete (fracpete at waikato dot ac dot nz)
- * @version $Revision: 1.2 $
+ * @version $Revision: 8281 $
  */
 public class NumericCleaner
   extends SimpleStreamFilter {
@@ -390,6 +390,7 @@ public class NumericCleaner
    */
   public Capabilities getCapabilities() {
     Capabilities result = super.getCapabilities();
+    result.disableAll();
 
     // attributes
     result.enableAllAttributes();
@@ -479,7 +480,7 @@ public class NumericCleaner
       }
       
       // decimals?
-      if (m_Decimals > -1) {
+      if (m_Decimals > -1 && !result.isMissing(i)) {
 	val = result.value(i);
 	val = StrictMath.round(val * factor) / factor;
 	result.setValue(i, val);
@@ -806,7 +807,7 @@ public class NumericCleaner
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 1.2 $");
+    return RevisionUtils.extract("$Revision: 8281 $");
   }
 
   /**
