@@ -21,8 +21,14 @@
 
 package weka.filters.unsupervised.attribute;
 
+import java.util.Collections;
+import java.util.Enumeration;
+import java.util.HashSet;
+import java.util.Vector;
+
 import weka.core.Attribute;
 import weka.core.Capabilities;
+import weka.core.Capabilities.Capability;
 import weka.core.FastVector;
 import weka.core.Instance;
 import weka.core.Instances;
@@ -31,34 +37,35 @@ import weka.core.Range;
 import weka.core.RevisionUtils;
 import weka.core.SparseInstance;
 import weka.core.Utils;
-import weka.core.Capabilities.Capability;
 import weka.filters.SimpleBatchFilter;
 
-import java.util.Collections;
-import java.util.Enumeration;
-import java.util.HashSet;
-import java.util.Vector;
-
 /**
- <!-- globalinfo-start -->
- * A filter for turning numeric attributes into nominal ones. Unlike discretization, it just takes all numeric values and adds them to the list of nominal values of that attribute. Useful after CSV imports, to enforce certain attributes to become nominal, e.g., the class attribute, containing values from 1 to 5.
+ * <!-- globalinfo-start --> A filter for turning numeric attributes into
+ * nominal ones. Unlike discretization, it just takes all numeric values and
+ * adds them to the list of nominal values of that attribute. Useful after CSV
+ * imports, to enforce certain attributes to become nominal, e.g., the class
+ * attribute, containing values from 1 to 5.
  * <p/>
- <!-- globalinfo-end -->
+ * <!-- globalinfo-end -->
  * 
- <!-- options-start -->
- * Valid options are: <p/>
+ * <!-- options-start --> Valid options are:
+ * <p/>
  * 
- * <pre> -R &lt;col1,col2-col4,...&gt;
+ * <pre>
+ * -R &lt;col1,col2-col4,...&gt;
  *  Specifies list of columns to Discretize. First and last are valid indexes.
- *  (default: first-last)</pre>
+ *  (default: first-last)
+ * </pre>
  * 
- * <pre> -V
- *  Invert matching sense of column indexes.</pre>
+ * <pre>
+ * -V
+ *  Invert matching sense of column indexes.
+ * </pre>
  * 
- <!-- options-end -->
- *
- * @author  fracpete (fracpete at waikato dot ac dot nz)
- * @version $Revision: 5543 $
+ * <!-- options-end -->
+ * 
+ * @author fracpete (fracpete at waikato dot ac dot nz)
+ * @version $Revision: 10988 $
  */
 public class NumericToNominal
   extends SimpleBatchFilter {
@@ -68,7 +75,7 @@ public class NumericToNominal
 
   /** the maximum number of decimals to use */
   protected final static int MAX_DECIMALS = 6;
-  
+
   /** Stores which columns to turn into nominals */
   protected Range m_Cols = new Range("first-last");
 
@@ -77,13 +84,14 @@ public class NumericToNominal
 
   /**
    * Returns a string describing this filter
-   *
-   * @return 		a description of the filter suitable for
-   * 			displaying in the explorer/experimenter gui
+   * 
+   * @return a description of the filter suitable for displaying in the
+   *         explorer/experimenter gui
    */
+  @Override
   public String globalInfo() {
-    return 
-        "A filter for turning numeric attributes into nominal ones. Unlike "
+    return
+    "A filter for turning numeric attributes into nominal ones. Unlike "
       + "discretization, it just takes all numeric values and adds them to "
       + "the list of nominal values of that attribute. Useful after CSV "
       + "imports, to enforce certain attributes to become nominal, e.g., "
@@ -92,103 +100,115 @@ public class NumericToNominal
 
   /**
    * Gets an enumeration describing the available options.
-   *
-   * @return 		an enumeration of all the available options.
+   * 
+   * @return an enumeration of all the available options.
    */
+  @Override
   public Enumeration listOptions() {
     Vector result = new Vector();
 
     result.addElement(new Option(
-	"\tSpecifies list of columns to Discretize. First"
-	+ " and last are valid indexes.\n"
-	+ "\t(default: first-last)",
-	"R", 1, "-R <col1,col2-col4,...>"));
+      "\tSpecifies list of columns to Discretize. First"
+        + " and last are valid indexes.\n"
+        + "\t(default: first-last)",
+      "R", 1, "-R <col1,col2-col4,...>"));
 
     result.addElement(new Option(
-	"\tInvert matching sense of column indexes.",
-	"V", 0, "-V"));
+      "\tInvert matching sense of column indexes.",
+      "V", 0, "-V"));
 
     return result.elements();
   }
 
   /**
-   * Parses a given list of options. <p/>
+   * Parses a given list of options.
+   * <p/>
    * 
-   <!-- options-start -->
-   * Valid options are: <p/>
+   * <!-- options-start --> Valid options are:
+   * <p/>
    * 
-   * <pre> -R &lt;col1,col2-col4,...&gt;
+   * <pre>
+   * -R &lt;col1,col2-col4,...&gt;
    *  Specifies list of columns to Discretize. First and last are valid indexes.
-   *  (default: first-last)</pre>
+   *  (default: first-last)
+   * </pre>
    * 
-   * <pre> -V
-   *  Invert matching sense of column indexes.</pre>
+   * <pre>
+   * -V
+   *  Invert matching sense of column indexes.
+   * </pre>
+   * 
+   * <!-- options-end -->
    * 
-   <!-- options-end -->
-   *
    * @param options the list of options as an array of strings
    * @throws Exception if an option is not supported
    */
+  @Override
   public void setOptions(String[] options) throws Exception {
-    String	tmpStr;
+    String tmpStr;
 
     super.setOptions(options);
-    
+
     setInvertSelection(Utils.getFlag('V', options));
 
     tmpStr = Utils.getOption('R', options);
-    if (tmpStr.length() != 0)
+    if (tmpStr.length() != 0) {
       setAttributeIndices(tmpStr);
-    else
+    } else {
       setAttributeIndices(m_DefaultCols);
+    }
 
-    if (getInputFormat() != null)
+    if (getInputFormat() != null) {
       setInputFormat(getInputFormat());
+    }
   }
 
   /**
    * Gets the current settings of the filter.
-   *
+   * 
    * @return an array of strings suitable for passing to setOptions
    */
+  @Override
   public String[] getOptions() {
-    int       i;
-    Vector    result;
-    String[]  options;
+    int i;
+    Vector result;
+    String[] options;
 
     result = new Vector();
     options = super.getOptions();
-    for (i = 0; i < options.length; i++)
+    for (i = 0; i < options.length; i++) {
       result.add(options[i]);
+    }
 
     if (!getAttributeIndices().equals("")) {
       result.add("-R");
       result.add(getAttributeIndices());
     }
 
-    if (getInvertSelection())
+    if (getInvertSelection()) {
       result.add("-V");
+    }
 
-    return (String[]) result.toArray(new String[result.size()]);	  
+    return (String[]) result.toArray(new String[result.size()]);
   }
 
   /**
    * Returns the tip text for this property
-   *
-   * @return 		tip text for this property suitable for
-   * 			displaying in the explorer/experimenter gui
+   * 
+   * @return tip text for this property suitable for displaying in the
+   *         explorer/experimenter gui
    */
   public String invertSelectionTipText() {
-    return 
-        "Set attribute selection mode. If false, only selected"
+    return
+    "Set attribute selection mode. If false, only selected"
       + " (numeric) attributes in the range will be 'nominalized'; if"
       + " true, only non-selected attributes will be 'nominalized'.";
   }
 
   /**
    * Gets whether the supplied columns are to be worked on or the others.
-   *
-   * @return 		true if the supplied columns will be worked on
+   * 
+   * @return true if the supplied columns will be worked on
    */
   public boolean getInvertSelection() {
     return m_Cols.getInvert();
@@ -196,10 +216,10 @@ public class NumericToNominal
 
   /**
    * Sets whether selected columns should be worked on or all the others apart
-   * from these. If true all the other columns are considered for 
+   * from these. If true all the other columns are considered for
    * "nominalization".
-   *
-   * @param value 	the new invert setting
+   * 
+   * @param value the new invert setting
    */
   public void setInvertSelection(boolean value) {
     m_Cols.setInvert(value);
@@ -207,9 +227,9 @@ public class NumericToNominal
 
   /**
    * Returns the tip text for this property
-   *
-   * @return 		tip text for this property suitable for
-   * 			displaying in the explorer/experimenter gui
+   * 
+   * @return tip text for this property suitable for displaying in the
+   *         explorer/experimenter gui
    */
   public String attributeIndicesTipText() {
     return "Specify range of attributes to act on."
@@ -220,21 +240,21 @@ public class NumericToNominal
 
   /**
    * Gets the current range selection
-   *
-   * @return 		a string containing a comma separated list of ranges
+   * 
+   * @return a string containing a comma separated list of ranges
    */
   public String getAttributeIndices() {
     return m_Cols.getRanges();
   }
 
   /**
-   * Sets which attributes are to be "nominalized" (only numeric
-   * attributes among the selection will be transformed).
-   *
-   * @param value 	a string representing the list of attributes. Since
-   * 			the string will typically come from a user, attributes 
-   * 			are indexed from 1. <br> eg: first-3,5,6-last
-   * @throws IllegalArgumentException if an invalid range list is supplied 
+   * Sets which attributes are to be "nominalized" (only numeric attributes
+   * among the selection will be transformed).
+   * 
+   * @param value a string representing the list of attributes. Since the string
+   *          will typically come from a user, attributes are indexed from 1. <br>
+   *          eg: first-3,5,6-last
+   * @throws IllegalArgumentException if an invalid range list is supplied
    */
   public void setAttributeIndices(String value) {
     m_Cols.setRanges(value);
@@ -243,22 +263,23 @@ public class NumericToNominal
   /**
    * Sets which attributes are to be transoformed to nominal. (only numeric
    * attributes among the selection will be transformed).
-   *
-   * @param value 	an array containing indexes of attributes to nominalize.
-   * 			Since the array will typically come from a program, 
-   * 			attributes are indexed from 0.
-   * @throws IllegalArgumentException if an invalid set of ranges is supplied 
+   * 
+   * @param value an array containing indexes of attributes to nominalize. Since
+   *          the array will typically come from a program, attributes are
+   *          indexed from 0.
+   * @throws IllegalArgumentException if an invalid set of ranges is supplied
    */
   public void setAttributeIndicesArray(int[] value) {
     setAttributeIndices(Range.indicesToRangeList(value));
   }
 
-  /** 
+  /**
    * Returns the Capabilities of this filter.
-   *
-   * @return            the capabilities of this object
-   * @see               Capabilities
+   * 
+   * @return the capabilities of this object
+   * @see Capabilities
    */
+  @Override
   public Capabilities getCapabilities() {
     Capabilities result = super.getCapabilities();
     result.disableAll();
@@ -266,163 +287,181 @@ public class NumericToNominal
     // attributes
     result.enableAllAttributes();
     result.enable(Capability.MISSING_VALUES);
-    
+
     // class
     result.enableAllClasses();
     result.enable(Capability.MISSING_CLASS_VALUES);
     result.enable(Capability.NO_CLASS);
-    
+
     return result;
   }
 
   /**
-   * Determines the output format based on the input format and returns 
-   * this. In case the output format cannot be returned immediately, i.e.,
-   * immediateOutputFormat() returns false, then this method will be called
-   * from batchFinished().
-   *
-   * @param inputFormat     the input format to base the output format on
-   * @return                the output format
-   * @throws Exception      in case the determination goes wrong
-   * @see   #hasImmediateOutputFormat()
-   * @see   #batchFinished()
+   * Determines the output format based on the input format and returns this. In
+   * case the output format cannot be returned immediately, i.e.,
+   * immediateOutputFormat() returns false, then this method will be called from
+   * batchFinished().
+   * 
+   * @param inputFormat the input format to base the output format on
+   * @return the output format
+   * @throws Exception in case the determination goes wrong
+   * @see #hasImmediateOutputFormat()
+   * @see #batchFinished()
    */
+  @Override
   protected Instances determineOutputFormat(Instances inputFormat)
-      throws Exception {
-    
-    Instances 	data;
-    Instances	result;
-    FastVector	atts;
-    FastVector	values;
-    HashSet	hash;
-    int		i;
-    int		n;
-    boolean	isDate;
-    Instance	inst;
-    Vector	sorted;
+    throws Exception {
+
+    Instances data;
+    Instances result;
+    FastVector atts;
+    FastVector values;
+    HashSet hash;
+    int i;
+    int n;
+    boolean isDate;
+    Instance inst;
+    Vector sorted;
 
     m_Cols.setUpper(inputFormat.numAttributes() - 1);
     data = new Instances(inputFormat);
     atts = new FastVector();
     for (i = 0; i < data.numAttributes(); i++) {
       if (!m_Cols.isInRange(i) || !data.attribute(i).isNumeric()) {
-	atts.addElement(data.attribute(i));
-	continue;
+        atts.addElement(data.attribute(i));
+        continue;
       }
-      
+
       // date attribute?
       isDate = (data.attribute(i).type() == Attribute.DATE);
-      
+
       // determine all available attribtues in dataset
-      hash   = new HashSet();
+      hash = new HashSet();
       for (n = 0; n < data.numInstances(); n++) {
-	inst = data.instance(n);
-	if (inst.isMissing(i))
-	  continue;
-	
-	if (isDate)
-	  hash.add(inst.stringValue(i));
-	else
-	  hash.add(new Double(inst.value(i)));
+        inst = data.instance(n);
+        if (inst.isMissing(i)) {
+          continue;
+        }
+
+        if (isDate) {
+          hash.add(inst.stringValue(i));
+        } else {
+          hash.add(new Double(inst.value(i)));
+        }
       }
-      
+
       // sort values
       sorted = new Vector();
-      for (Object o: hash)
-	sorted.add(o);
+      for (Object o : hash) {
+        sorted.add(o);
+      }
       Collections.sort(sorted);
-      
+
       // create attribute from sorted values
       values = new FastVector();
-      for (Object o: sorted) {
-	if (isDate)
-	  values.addElement(
-	      o.toString());
-	else
-	  values.addElement(
-	      Utils.doubleToString(((Double) o).doubleValue(), MAX_DECIMALS));
+      for (Object o : sorted) {
+        if (isDate) {
+          values.addElement(
+            o.toString());
+        } else {
+          values.addElement(
+            Utils.doubleToString(((Double) o).doubleValue(), MAX_DECIMALS));
+        }
       }
-      atts.addElement(new Attribute(data.attribute(i).name(), values));
+      Attribute newAtt = new Attribute(data.attribute(i).name(), values);
+      newAtt.setWeight(data.attribute(i).weight());
+      atts.addElement(newAtt);
     }
-    
+
     result = new Instances(inputFormat.relationName(), atts, 0);
     result.setClassIndex(inputFormat.classIndex());
-    
+
     return result;
   }
 
   /**
-   * Processes the given data (may change the provided dataset) and returns
-   * the modified version. This method is called in batchFinished().
-   *
-   * @param instances   the data to process
-   * @return            the modified data
-   * @throws Exception  in case the processing goes wrong
-   * @see               #batchFinished()
+   * Processes the given data (may change the provided dataset) and returns the
+   * modified version. This method is called in batchFinished().
+   * 
+   * @param instances the data to process
+   * @return the modified data
+   * @throws Exception in case the processing goes wrong
+   * @see #batchFinished()
    */
+  @Override
   protected Instances process(Instances instances) throws Exception {
-    Instances	result;
-    int		i;
-    int		n;
-    double[]	values;
-    String	value;
-    Instance	inst;
-    Instance	newInst;
-    
-    // we need the complete input data!
-    if (!isFirstBatchDone())
-      setOutputFormat(determineOutputFormat(getInputFormat()));
-    
-    result = new Instances(getOutputFormat());
-    
-    for (i = 0; i < instances.numInstances(); i++) {
-      inst   = instances.instance(i);
-      values = inst.toDoubleArray();
-      
-      for (n = 0; n < values.length; n++) {
-	if (    !m_Cols.isInRange(n)
-	     || !instances.attribute(n).isNumeric() 
-	     || inst.isMissing(n) )
-	  continue;
+    Instances result;
+    int i;
+    int n;
+    double[] values;
+    String value;
+    Instance inst;
+    Instance newInst;
 
-	// get index of value
-	if (instances.attribute(n).type() == Attribute.DATE)
-	  value = inst.stringValue(n);
-	else
-	  value = Utils.doubleToString(inst.value(n), MAX_DECIMALS);
-	
-	values[n] = result.attribute(n).indexOfValue(value);
+    // we need the complete input data!
+    if (!isFirstBatchDone()) {
+      setOutputFormat(determineOutputFormat(getInputFormat()));
+    }
+
+    result = new Instances(getOutputFormat());
+
+    for (i = 0; i < instances.numInstances(); i++) {
+      inst = instances.instance(i);
+      values = inst.toDoubleArray();
+
+      for (n = 0; n < values.length; n++) {
+        if (!m_Cols.isInRange(n)
+          || !instances.attribute(n).isNumeric()
+          || inst.isMissing(n)) {
+          continue;
+        }
+
+        // get index of value
+        if (instances.attribute(n).type() == Attribute.DATE) {
+          value = inst.stringValue(n);
+        } else {
+          value = Utils.doubleToString(inst.value(n), MAX_DECIMALS);
+        }
+
+        int index = result.attribute(n).indexOfValue(value);
+        if (index == -1) {
+          values[n] = Instance.missingValue();
+        } else {
+          values[n] = index;
+        }
       }
-      
+
       // generate new instance
-      if (inst instanceof SparseInstance)
-	newInst = new SparseInstance(inst.weight(), values);
-      else
-	newInst = new Instance(inst.weight(), values);
-      
+      if (inst instanceof SparseInstance) {
+        newInst = new SparseInstance(inst.weight(), values);
+      } else {
+        newInst = new Instance(inst.weight(), values);
+      }
+
       // copy possible string, relational values
       newInst.setDataset(getOutputFormat());
       copyValues(newInst, false, inst.dataset(), getOutputFormat());
-      
+
       result.add(newInst);
     }
-    
+
     return result;
   }
-  
+
   /**
    * Returns the revision string.
    * 
-   * @return		the revision
+   * @return the revision
    */
+  @Override
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 5543 $");
+    return RevisionUtils.extract("$Revision: 10988 $");
   }
 
   /**
    * Runs the filter with the given parameters. Use -h to list options.
    * 
-   * @param args	the commandline options
+   * @param args the commandline options
    */
   public static void main(String[] args) {
     runFilter(new NumericToNominal(), args);
