@@ -75,7 +75,7 @@ import java.util.Vector;
  <!-- options-end -->
  *
  * @author FracPete (fracpete at waikato dot ac dot nz)
- * @version $Revision: 5548 $
+ * @version $Revision: 8972 $
  */
 public class RemoveFrequentValues 
    extends Filter 
@@ -467,7 +467,9 @@ public class RemoveFrequentValues
          newVals.addElement(oldAtt.value(selection[i]));
       }
       instanceInfo.deleteAttributeAt(m_AttIndex.getIndex());
-      instanceInfo.insertAttributeAt(new Attribute(oldAtt.name(), newVals),
+      Attribute newAtt = new Attribute(oldAtt.name(), newVals);
+      newAtt.setWeight(oldAtt.weight());
+      instanceInfo.insertAttributeAt(newAtt,
             m_AttIndex.getIndex());
       m_NominalMapping = new int [oldAtt.numValues()];
       for (i = 0; i < m_NominalMapping.length; i++) {
@@ -558,7 +560,10 @@ public class RemoveFrequentValues
       // value if m_ModifyHeader is set
       for (i = 0; i < getInputFormat().numInstances(); i++) {
          instance = getInputFormat().instance(i);
-      
+         if (instance.isMissing(m_AttIndex.getIndex())) {
+           push(instance);
+           continue;
+         }      
          if (m_Values.contains(instance.stringValue(m_AttIndex.getIndex()))) {
             if (getModifyHeader()) {
                instance.setValue(m_AttIndex.getIndex(),
@@ -631,7 +636,7 @@ public class RemoveFrequentValues
     * @return		the revision
     */
    public String getRevision() {
-     return RevisionUtils.extract("$Revision: 5548 $");
+     return RevisionUtils.extract("$Revision: 8972 $");
    }
    
    /**
