@@ -21,18 +21,21 @@
  */
 package weka.gui;
 
+import weka.core.ClassDiscovery;
+import weka.core.Utils;
+import weka.core.ClassDiscovery.StringCompare;
+
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.FileOutputStream;
+import java.util.Collections;
 import java.util.Enumeration;
+import java.util.HashSet;
 import java.util.Hashtable;
 import java.util.Properties;
 import java.util.StringTokenizer;
 import java.util.Vector;
 
-import weka.core.ClassDiscovery;
-import weka.core.Utils;
-
 /**
  * This class can generate the properties object that is normally loaded from
  * the <code>GenericObjectEditor.props</code> file (= PROPERTY_FILE). It takes
@@ -75,7 +78,7 @@ import weka.core.Utils;
  * @see GenericObjectEditor
  * @see weka.core.ClassDiscovery
  * @author FracPete (fracpete at waikato dot ac dot nz)
- * @version $Revision: 1.11 $
+ * @version $Revision: 7059 $
  */
 public class GenericPropertiesCreator {
   
@@ -260,7 +263,7 @@ public class GenericPropertiesCreator {
    */
   protected void loadInputProperties()  {
     if (VERBOSE)
-      System.out.println("Loading '" + getInputFilename() + "'...");
+      System.out.println(Messages.getInstance().getString("GenericPropertiesCreator_LoadInputProperties_Text_First") + getInputFilename() + Messages.getInstance().getString("GenericPropertiesCreator_LoadInputProperties_Text_Second"));
     m_InputProperties = new Properties();
     try {
       File f = new File(getInputFilename());
@@ -313,6 +316,16 @@ public class GenericPropertiesCreator {
     if (getInputProperties() == null)
       loadInputProperties();
     
+    // check our classloader against the system one - if different then
+    // return false (as dynamic classloading only works for classes discoverable
+    // in the system classpath
+    if (!ClassLoader.getSystemClassLoader().equals(this.getClass().getClassLoader())) {
+      if (Boolean.parseBoolean(getInputProperties().getProperty(USE_DYNAMIC, "true")) == true) {
+        System.out.println(Messages.getInstance().getString("GenericPropertiesCreator_UseDynamic_Text"));
+      }
+      return false;
+    }
+    
     return Boolean.parseBoolean(
 	getInputProperties().getProperty(USE_DYNAMIC, "true"));
   }
@@ -422,6 +435,7 @@ public class GenericPropertiesCreator {
     String            pkg;
     StringTokenizer   tok;
     Vector            classes;
+    HashSet           names;
     int               i;
     
     m_OutputProperties = new Properties();
@@ -431,7 +445,8 @@ public class GenericPropertiesCreator {
       if (key.equals(USE_DYNAMIC))
 	continue;
       tok   = new StringTokenizer(m_InputProperties.getProperty(key), ",");
-      value = "";
+      names = new HashSet();
+      
       // get classes for all packages
       while (tok.hasMoreTokens()) {
         pkg = tok.nextToken().trim();
@@ -440,7 +455,7 @@ public class GenericPropertiesCreator {
           classes = ClassDiscovery.find(Class.forName(key), pkg);
         }
         catch (Exception e) {
-          System.out.println("Problem with '" + key + "': " + e);
+          System.out.println(Messages.getInstance().getString("GenericPropertiesCreator_GenerateOutputProperties_Text_First") + key + Messages.getInstance().getString("GenericPropertiesCreator_GenerateOutputProperties_Text_Second") + e);
           classes = new Vector();
         }
         
@@ -451,13 +466,24 @@ public class GenericPropertiesCreator {
           // some classes should not be listed for some keys
           if (!isValidClassname(key, classes.get(i).toString()))
             continue;
-          if (!value.equals(""))
-            value += ",";
-          value += classes.get(i).toString();
+          names.add(classes.get(i));
         }
-        if (VERBOSE)
-          System.out.println(pkg + " -> " + value);
       }
+      
+      // generate list
+      value   = "";
+      classes = new Vector();
+      classes.addAll(names);
+      Collections.sort(classes, new StringCompare());
+      for (i = 0; i < classes.size(); i++) {
+        if (!value.equals(""))
+          value += ",";
+        value += classes.get(i).toString();
+      }
+      if (VERBOSE)
+        System.out.println(pkg + " -> " + value);
+      
+      // set value
       m_OutputProperties.setProperty(key, value);
     }
   }
@@ -471,10 +497,10 @@ public class GenericPropertiesCreator {
    */
   protected void storeOutputProperties() throws Exception {
     if (VERBOSE)
-      System.out.println("Saving '" + getOutputFilename() + "'...");
+      System.out.println(Messages.getInstance().getString("GenericPropertiesCreator_StoreOutputProperties_Text_First") + getOutputFilename() + Messages.getInstance().getString("GenericPropertiesCreator_StoreOutputProperties_Text_Second"));
     m_OutputProperties.store(
         new FileOutputStream(getOutputFilename()), 
-        " Customises the list of options given by the GenericObjectEditor\n# for various superclasses.");
+        Messages.getInstance().getString("GenericPropertiesCreator_StoreOutputProperties_Text_Third"));
   }
   
   /**
@@ -550,7 +576,7 @@ public class GenericPropertiesCreator {
       c.setOutputFilename(args[1]);
     }
     else {
-      System.out.println("usage: " + GenericPropertiesCreator.class.getName() + " [<input.props>] [<output.props>]");
+      System.out.println(Messages.getInstance().getString("GenericPropertiesCreator_Main_Text_First") + GenericPropertiesCreator.class.getName() + Messages.getInstance().getString("GenericPropertiesCreator_Main_Text_Second"));
       System.exit(1);
     }
     
