@@ -35,14 +35,14 @@ import javax.swing.JPanel;
  * Bean that assigns a class attribute to a data set.
  *
  * @author Mark Hall
- * @version $Revision: 4806 $
+ * @version $Revision: 7439 $
  */
 public class ClassAssigner
   extends JPanel
   implements Visible, DataSourceListener, TrainingSetListener, TestSetListener,
 	     DataSource, TrainingSetProducer, TestSetProducer,
 	     BeanCommon, EventConstraints, Serializable,
-	     InstanceListener {
+	     InstanceListener, StructureProducer {
 
   /** for serialization */
   private static final long serialVersionUID = 4011131665025817924L;
@@ -77,8 +77,7 @@ public class ClassAssigner
    * @return a <code>String</code> value
    */
   public String globalInfo() {
-    return "Designate which column is to be considered the class column "
-      +"in incoming data.";
+    return Messages.getInstance().getString("ClassAssigner_GlobalInfo_Text");
   }
 
   public ClassAssigner() {
@@ -110,7 +109,80 @@ public class ClassAssigner
    * @return a <code>String</code> value
    */
   public String classColumnTipText() {
-    return "Specify the number of the column that contains the class attribute";
+    return Messages.getInstance().getString("ClassAssigner_ClassColumnTipText_Text");
+  }
+  
+  private Instances getUpstreamStructure() {
+    if (m_dataProvider != null && m_dataProvider instanceof StructureProducer) {
+      return ((StructureProducer)m_dataProvider).getStructure("dataSet");
+    }
+    if (m_trainingProvider != null && 
+        m_trainingProvider instanceof StructureProducer) {
+      return ((StructureProducer)m_trainingProvider).getStructure("trainingSet");
+    }
+    if (m_testProvider != null && m_testProvider instanceof StructureProducer) {
+      return ((StructureProducer)m_testProvider).getStructure("testSet");
+    }
+    if (m_instanceProvider != null && 
+        m_instanceProvider instanceof StructureProducer) {
+      return ((StructureProducer)m_instanceProvider).getStructure("instance");
+    }
+    return null;
+  }
+  
+  /**
+   * Get the structure of the output encapsulated in the named
+   * event. If the structure can't be determined in advance of
+   * seeing input, or this StructureProducer does not generate
+   * the named event, null should be returned.
+   * 
+   * @param eventName the name of the output event that encapsulates
+   * the requested output.
+   * 
+   * @return the structure of the output encapsulated in the named
+   * event or null if it can't be determined in advance of seeing input
+   * or the named event is not generated by this StructureProduce.
+   */
+  public Instances getStructure(String eventName) {
+    if (!eventName.equals("trainingSet") && !eventName.equals("testSet") && 
+        !eventName.equals("dataSet") && !eventName.equals("instance")) {
+      return null;
+    }
+    if (m_trainingProvider == null && m_testProvider == null && 
+        m_dataProvider == null && m_instanceProvider == null) {
+      return null;
+    }
+    
+    if (eventName.equals("dataSet") && m_dataListeners.size() == 0) {    
+      // downstream has asked for the structure of something that we
+      // are not producing at the moment
+      return null;
+    }
+    
+    if (eventName.equals("trainingSet") && m_trainingListeners.size() == 0) {    
+      // downstream has asked for the structure of something that we
+      // are not producing at the moment
+      return null;
+    }
+    
+    if (eventName.equals("testSet") && m_testListeners.size() == 0) {    
+      // downstream has asked for the structure of something that we
+      // are not producing at the moment
+      return null;
+    }
+    
+    if (eventName.equals("instance") && m_instanceListeners.size() == 0) {    
+      // downstream has asked for the structure of something that we
+      // are not producing at the moment
+      return null;
+    }
+    
+    if (m_connectedFormat == null) {
+      m_connectedFormat = getUpstreamStructure();
+    }
+    
+    assignClass(m_connectedFormat);
+    return m_connectedFormat;
   }
 
   /**
@@ -119,6 +191,21 @@ public class ClassAssigner
    * @return an <code>Instances</code> value
    */
   public Instances getConnectedFormat() {
+ // loaders will push instances format to us
+    // when the user makes configuration changes
+    // to the loader in the gui. However, if a fully
+    // configured flow is loaded then we won't get
+    // this information pushed to us until the
+    // flow is run. In this case we want to pull
+    // it (if possible) from upstream steps so
+    // that our customizer can provide the nice
+    // UI with the drop down box of class names.    
+    if (m_connectedFormat == null) {
+      // try and pull the incoming structure
+      // from the upstream step (if possible)
+      m_connectedFormat = getUpstreamStructure();
+    }
+    
     return m_connectedFormat;
   }
 
@@ -148,12 +235,24 @@ public class ClassAssigner
     Instances trainingSet = e.getTrainingSet();
     assignClass(trainingSet);
     notifyTrainingListeners(e);
+    
+    if (e.isStructureOnly()) {
+      m_connectedFormat = e.getTrainingSet();
+      // tell any listening customizers (or other
+      notifyDataFormatListeners();
+    }
   }
 
   public void acceptTestSet(TestSetEvent e) {
     Instances testSet = e.getTestSet();
     assignClass(testSet);
     notifyTestListeners(e);
+    
+    if (e.isStructureOnly()) {
+      m_connectedFormat = e.getTestSet();
+      // tell any listening customizers (or other
+      notifyDataFormatListeners();
+    }
   }
 
   public void acceptInstance(InstanceEvent e) {
@@ -166,7 +265,7 @@ public class ClassAssigner
       notifyInstanceListeners(e);
 
       // tell any listening customizers (or other interested parties)
-      System.err.println("Notifying customizer...");
+      System.err.println(Messages.getInstance().getString("ClassAssigner_AcceptInstance_Error_Text"));
       notifyDataFormatListeners();
     } else {
       //      Instances dataSet = e.getInstance().dataset();
@@ -185,8 +284,7 @@ public class ClassAssigner
       classCol = Integer.parseInt(m_classColumn) - 1;
       if (/*classCol < 0 ||*/ classCol > dataSet.numAttributes()-1) {
 	if (m_logger != null) {
-	  m_logger.logMessage("Class column outside range of data "
-			      +"(ClassAssigner)");
+	  m_logger.logMessage(Messages.getInstance().getString("ClassAssigner_AssignClass_LogMessage_Text"));
 	}
       } else {
 	dataSet.setClassIndex(classCol);
@@ -201,8 +299,7 @@ public class ClassAssigner
     }
     if (l.size() > 0) {
       for(int i = 0; i < l.size(); i++) {
-	System.err.println("Notifying test listeners "
-			   +"(ClassAssigner)");
+	System.err.println(Messages.getInstance().getString("ClassAssigner_NotifyTestListeners_Error_Text"));
 	((TestSetListener)l.elementAt(i)).acceptTestSet(tse);
       }
     }
@@ -215,8 +312,7 @@ public class ClassAssigner
     }
     if (l.size() > 0) {
       for(int i = 0; i < l.size(); i++) {
-	System.err.println("Notifying training listeners "
-			   +"(ClassAssigner)");
+	System.err.println(Messages.getInstance().getString("ClassAssigner_NotifyTrainingListeners_Error_Text"));
 	((TrainingSetListener)l.elementAt(i)).acceptTrainingSet(tse);
       }
     }
@@ -229,8 +325,7 @@ public class ClassAssigner
     }
     if (l.size() > 0) {
       for(int i = 0; i < l.size(); i++) {
-	System.err.println("Notifying data listeners "
-			   +"(ClassAssigner)");
+	System.err.println(Messages.getInstance().getString("ClassAssigner_NotifyDataListeners_Error_Text"));
 	((DataSourceListener)l.elementAt(i)).acceptDataSet(tse);
       }
     }
@@ -398,6 +493,7 @@ public class ClassAssigner
       } else if (eventName.compareTo("instance") == 0) {
 	m_instanceProvider = source;
       }
+      m_connectedFormat = null;
     }
   }
 
@@ -433,6 +529,7 @@ public class ClassAssigner
 	m_instanceProvider = null;
       }
     }
+    m_connectedFormat = null;
   }
   
   public void setLog(weka.gui.Logger logger) {
@@ -440,7 +537,22 @@ public class ClassAssigner
   }
 
   public void stop() {
-    // nothing to do
+    // Pass on to upstream beans
+    if (m_trainingProvider != null && m_trainingProvider instanceof BeanCommon) {
+      ((BeanCommon)m_trainingProvider).stop();
+    }
+    
+    if (m_testProvider != null && m_testProvider instanceof BeanCommon) {
+      ((BeanCommon)m_testProvider).stop();
+    }
+    
+    if (m_dataProvider != null && m_dataProvider instanceof BeanCommon) {
+      ((BeanCommon)m_dataProvider).stop();
+    }
+    
+    if (m_instanceProvider != null && m_instanceProvider instanceof BeanCommon) {
+      ((BeanCommon)m_instanceProvider).stop();
+    }
   }
   
   /**
