@@ -45,7 +45,7 @@ import javax.swing.JPanel;
  * A wrapper bean for Weka filters
  *
  * @author <a href="mailto:mhall@cs.waikato.ac.nz">Mark Hall</a>
- * @version $Revision: 7059 $
+ * @version $Revision: 9967 $
  */
 public class Filter
   extends JPanel
@@ -69,7 +69,7 @@ public class Filter
   private static int FILTERING_TEST = 2;
   private int m_state = IDLE;
 
-  protected Thread m_filterThread = null;
+  protected transient Thread m_filterThread = null;
 
   private transient Instances m_trainingSet;
   private transient Instances m_testingSet;
@@ -547,6 +547,7 @@ public class Filter
 		    }
 		  }
 		  block(false);
+	          m_filterThread = null;
 		}
 	      }
 	    };
@@ -629,6 +630,7 @@ public class Filter
 		  }
 		}
 		block(false);
+	        m_filterThread = null;
 	      }
 	    }
 	  };
