@@ -22,6 +22,8 @@
 
 package weka.gui.beans;
 
+import weka.core.Environment;
+import weka.core.EnvironmentHandler;
 import weka.core.Instance;
 import weka.core.Instances;
 import weka.core.OptionHandler;
@@ -36,7 +38,9 @@ import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.beans.EventSetDescriptor;
 import java.beans.beancontext.BeanContext;
+import java.io.File;
 import java.io.IOException;
+import java.io.ObjectInputStream;
 import java.io.ObjectStreamException;
 import java.util.Enumeration;
 import java.util.Vector;
@@ -47,15 +51,16 @@ import javax.swing.JButton;
  * Loads data sets using weka.core.converter classes
  *
  * @author <a href="mailto:mhall@cs.waikato.ac.nz">Mark Hall</a>
- * @version $Revision: 4813 $
+ * @version $Revision: 7458 $
  * @since 1.0
  * @see AbstractDataSource
  * @see UserRequestAcceptor
  */
 public class Loader
   extends AbstractDataSource 
-  implements Startable, UserRequestAcceptor, WekaWrapper,
-	     EventConstraints, BeanCommon {
+  implements Startable, /*UserRequestAcceptor,*/ WekaWrapper,
+	     EventConstraints, BeanCommon, EnvironmentHandler,
+	     StructureProducer {
 
   /** for serialization */
   private static final long serialVersionUID = 1993738191961163027L;
@@ -104,7 +109,12 @@ public class Loader
   /**
    * Logging
    */
-  protected Logger m_log;
+  protected transient Logger m_log;
+  
+  /**
+   * The environment variables.
+   */
+  protected transient Environment m_env;
   
   /**
    * Asked to stop?
@@ -136,11 +146,16 @@ public class Loader
           m_state = BATCH_LOADING;
 	}
 	
+	// Set environment variables
+	if (m_Loader instanceof EnvironmentHandler && m_env != null) {
+	  ((EnvironmentHandler)m_Loader).setEnvironment(m_env);
+	}
+	
 	String msg = statusMessagePrefix();
 	if (m_Loader instanceof FileSourcedConverter) {
-	  msg += "Loading " + ((FileSourcedConverter)m_Loader).retrieveFile().getName();
+	  msg += Messages.getInstance().getString("Loader_LoadThread_Msg_Text_First") + ((FileSourcedConverter)m_Loader).retrieveFile().getName();
 	} else {
-	  msg += "Loading...";
+	  msg += Messages.getInstance().getString("Loader_LoadThread_Msg_Text_Second");
 	}
 	if (m_log != null) {
 	  m_log.statusMessage(msg);
@@ -154,14 +169,15 @@ public class Loader
 	  Instances structure = null;
 	  try {
             m_Loader.reset();
+            m_Loader.setRetrieval(weka.core.converters.Loader.INCREMENTAL);
             //	    System.err.println("NOTIFYING STRUCTURE AVAIL");
 	    structure = m_Loader.getStructure();
 	    notifyStructureAvailable(structure);
 	  } catch (IOException e) {
 	    if (m_log != null) {
 	      m_log.statusMessage(statusMessagePrefix()
-	          +"ERROR (See log for details");
-	      m_log.logMessage("[Loader] " + statusMessagePrefix()
+	          + Messages.getInstance().getString("Loader_LoadThread_StatusMessage_Text_First"));
+	      m_log.logMessage(Messages.getInstance().getString("Loader_LoadThread_StatusMessage_Text_Second") + statusMessagePrefix()
 	          + " " + e.getMessage());
 	    }
 	    e.printStackTrace();
@@ -171,8 +187,8 @@ public class Loader
 	  } catch (IOException e) {
 	    if (m_log != null) {
 	      m_log.statusMessage(statusMessagePrefix()
-	          +"ERROR (See log for details");
-	      m_log.logMessage("[Loader] " + statusMessagePrefix()
+	          + Messages.getInstance().getString("Loader_LoadThread_StatusMessage_Text_Third"));
+	      m_log.logMessage(Messages.getInstance().getString("Loader_LoadThread_StatusMessage_Text_Fourth") + statusMessagePrefix()
 	          + " " + e.getMessage());
 	    }
 	    e.printStackTrace();
@@ -207,7 +223,7 @@ public class Loader
 //              m_visual.setText("" + z + " instances...");
               if (m_log != null) {
                 m_log.statusMessage(statusMessagePrefix() 
-                    + "Loaded " + z + " instances");
+                    + Messages.getInstance().getString("Loader_LoadThread_StatusMessage_Text_Fifth") + z + Messages.getInstance().getString("Loader_LoadThread_StatusMessage_Text_Sixth"));
               }
             }
 	  }
@@ -215,11 +231,12 @@ public class Loader
 //	  m_visual.setText(structure.relationName());
 	} else {
           m_Loader.reset();
+          m_Loader.setRetrieval(weka.core.converters.Loader.BATCH);
 	  m_dataSet = m_Loader.getDataSet();
 	  m_visual.setStatic();
 	  if (m_log != null) {
-	    m_log.logMessage("[Loader] " + statusMessagePrefix() 
-	        + " loaded " + m_dataSet.relationName());
+	    m_log.logMessage(Messages.getInstance().getString("Loader_LoadThread_LogMessage_Text_First") + statusMessagePrefix() 
+	        + Messages.getInstance().getString("Loader_LoadThread_LogMessage_Text_Second") + m_dataSet.relationName());
 	  }
 //	  m_visual.setText(m_dataSet.relationName());
 	  notifyDataSetLoaded(new DataSetEvent(m_DP, m_dataSet));
@@ -227,16 +244,16 @@ public class Loader
       } catch (Exception ex) {
         if (m_log != null) {
           m_log.statusMessage(statusMessagePrefix()
-              +"ERROR (See log for details");
-          m_log.logMessage("[Loader] " + statusMessagePrefix()
+              + Messages.getInstance().getString("Loader_LoadThread_StatusMessage_Text_Seventh"));
+          m_log.logMessage(Messages.getInstance().getString("Loader_LoadThread_StatusMessage_Text_Eighth") + statusMessagePrefix()
               + " " + ex.getMessage());
         }
 	ex.printStackTrace();
       } finally {
         if (Thread.currentThread().isInterrupted()) {
           if (m_log != null) {
-            m_log.logMessage("[Loader] " + statusMessagePrefix() 
-                + " loading interrupted!");
+            m_log.logMessage(Messages.getInstance().getString("Loader_LoadThread_LogMessage_Text_Third") + statusMessagePrefix() 
+                + Messages.getInstance().getString("Loader_LoadThread_LogMessage_Text_Fourth"));
           }
         }
 	m_ioThread = null;
@@ -246,7 +263,7 @@ public class Loader
         m_state = IDLE;
         m_stopped = false;
         if (m_log != null) {
-          m_log.statusMessage(statusMessagePrefix() + "Finished.");
+          m_log.statusMessage(statusMessagePrefix() + Messages.getInstance().getString("Loader_LoadThread_StatusMessage_Text_Nineth"));
         }
         block(false);
       }
@@ -276,7 +293,7 @@ public class Loader
   protected void appearanceFinal() {
     removeAll();
     setLayout(new BorderLayout());
-    JButton goButton = new JButton("Start...");
+    JButton goButton = new JButton(Messages.getInstance().getString("Loader_AppearanceFinal_GoButton_JButton_Text"));
     add(goButton, BorderLayout.CENTER);
     goButton.addActionListener(new ActionListener() {
 	public void actionPerformed(ActionEvent e) {
@@ -334,20 +351,62 @@ public class Loader
     }
     m_visual.setText(loaderName);
     
-    if(! (loader instanceof DatabaseLoader)) {
-      // try to load structure (if possible) and notify any listeners
-      try {
-        m_dataFormat = m_Loader.getStructure();
-        //      System.err.println(m_dataFormat);
-        System.out.println("[Loader] Notifying listeners of instance structure avail.");
-        notifyStructureAvailable(m_dataFormat);
-      }catch (Exception ex) {
-      }
-    }
-    
     // get global info
     m_globalInfo = KnowledgeFlowApp.getGlobalInfo(m_Loader);
   }
+  
+  protected void newFileSelected() throws Exception {
+    if(! (m_Loader instanceof DatabaseLoader)) {
+      newStructure();
+    }
+  }
+  
+  protected void newStructure() throws Exception {
+    if (m_Loader instanceof EnvironmentHandler && m_env != null) {
+      try {
+        ((EnvironmentHandler)m_Loader).setEnvironment(m_env);
+      } catch (Exception ex) {}
+    }
+    m_dataFormat = m_Loader.getStructure();
+//    System.out.println(Messages.getInstance().getString("Loader_NewFileSelected_Text"));
+//    notifyStructureAvailable(m_dataFormat);
+  }
+  
+  /**
+   * Get the structure of the output encapsulated in the named
+   * event. If the structure can't be determined in advance of
+   * seeing input, or this StructureProducer does not generate
+   * the named event, null should be returned.
+   * 
+   * @param eventName the name of the output event that encapsulates
+   * the requested output.
+   * 
+   * @return the structure of the output encapsulated in the named
+   * event or null if it can't be determined in advance of seeing input
+   * or the named event is not generated by this StructureProduce.
+   */
+  public Instances getStructure(String eventName) {
+    
+    if (!eventName.equals("dataSet") && !eventName.equals("instance")) {
+      return null;
+    }        
+    if (m_dataSetEventTargets > 0 && !eventName.equals("dataSet")) {
+      return null;
+    }
+    if (m_dataSetEventTargets == 0 && !eventName.equals("instance")) {
+      return null;
+    }
+    
+    try {
+      newStructure();
+      
+    } catch (Exception ex) {
+      //ex.printStackTrace();
+      System.err.println("[KnowledgeFlow/Loader] Warning: " + ex.getMessage());
+      m_dataFormat = null;
+    }
+    return m_dataFormat;
+  }
 
   /**
    * Get the loader
@@ -368,8 +427,7 @@ public class Loader
     {
 
     if (!(algorithm instanceof weka.core.converters.Loader)) { 
-      throw new IllegalArgumentException(algorithm.getClass()+" : incorrect "
-					 +"type of algorithm (Loader)");
+      throw new IllegalArgumentException(algorithm.getClass() + Messages.getInstance().getString("Loader_SetWrappedAlgorithm_IllegalArgumentException_Text"));
     }
     setLoader((weka.core.converters.Loader)algorithm);
   }
@@ -459,12 +517,18 @@ public class Loader
    *
    * @return an <code>Enumeration</code> value
    */
-  public Enumeration enumerateRequests() {
+  /*public Enumeration enumerateRequests() {
     Vector newVector = new Vector(0);
     boolean ok = true;
     if (m_ioThread == null) {
       if (m_Loader instanceof FileSourcedConverter) {
-	if (! ((FileSourcedConverter) m_Loader).retrieveFile().isFile()) {
+        String temp = ((FileSourcedConverter) m_Loader).retrieveFile().getPath();
+        Environment env = (m_env == null) ? Environment.getSystemWide() : m_env;
+        try {
+          temp = env.substitute(temp);
+        } catch (Exception ex) {}
+        File tempF = new File(temp);
+	if (!tempF.isFile()) {
 	  ok = false;
 	}
       }
@@ -475,7 +539,7 @@ public class Loader
       newVector.addElement(entry);
     }
     return newVector.elements();
-  }
+  } */
 
   /**
    * Perform the named request
@@ -483,14 +547,14 @@ public class Loader
    * @param request a <code>String</code> value
    * @exception IllegalArgumentException if an error occurs
    */
-  public void performRequest(String request) {
+  /*public void performRequest(String request) {
     if (request.compareTo("Start loading") == 0) {
       startLoading();
     } else {
       throw new IllegalArgumentException(request
 					 + " not supported (Loader)");
     }
-  }
+  } */
 
   /**
    * Start loading
@@ -502,6 +566,38 @@ public class Loader
     block(true);
   }
   
+  /**
+   * Gets a string that describes the start action. The
+   * KnowledgeFlow uses this in the popup contextual menu
+   * for the component. The string can be proceeded by
+   * a '$' character to indicate that the component can't
+   * be started at present.
+   * 
+   * @return a string describing the start action.
+   */
+  public String getStartMessage() {
+    boolean ok = true;
+    String entry = Messages.getInstance().getString("Loader_GetStartMessage_Entry_Text");
+    if (m_ioThread == null) {
+      if (m_Loader instanceof FileSourcedConverter) {
+        String temp = ((FileSourcedConverter) m_Loader).retrieveFile().getPath();
+        Environment env = (m_env == null) ? Environment.getSystemWide() : m_env;
+        try {
+          temp = env.substitute(temp);
+        } catch (Exception ex) {}
+        File tempF = new File(temp);
+        if (!tempF.isFile()) {
+          ok = false;
+        }
+      }
+      if (!ok) {
+        entry = "$"+entry;
+      }
+    }
+    
+    return entry;
+  }
+  
   /**
    * Function used to stop code that calls acceptTrainingSet. This is 
    * needed as classifier construction is performed inside a separate
@@ -679,6 +775,16 @@ public class Loader
     m_log = logger;
   }
   
+  /**
+   * Set environment variables to use.
+   * 
+   * @param env the environment variables to
+   * use
+   */
+  public void setEnvironment(Environment env) {
+    m_env = env;
+  }
+  
   /**
    * Returns true if, at this time, 
    * the object will accept a connection via the supplied
@@ -751,5 +857,14 @@ public class Loader
         ? Utils.joinOptions(((OptionHandler)m_Loader).getOptions()) + "|"
             : "");
   }
-}
-
+  
+  // Custom de-serialization in order to set default
+  // environment variables on de-serialization
+  private void readObject(ObjectInputStream aStream) 
+    throws IOException, ClassNotFoundException {
+    aStream.defaultReadObject();
+    
+    // set a default environment to use
+    m_env = Environment.getSystemWide();
+  }
+}
\ No newline at end of file
