@@ -25,6 +25,7 @@ import weka.core.converters.ConverterUtils;
 import weka.core.xml.XMLBasicSerialization;
 import weka.core.xml.XMLDocument;
 import weka.core.Environment;
+import weka.core.EnvironmentHandler;
 import weka.gui.beans.BeanConnection;
 import weka.gui.beans.BeanInstance;
 import weka.gui.beans.BeanVisual;
@@ -60,7 +61,7 @@ import org.w3c.dom.NodeList;
  * <br>
  * 
  * @author FracPete (fracpete at waikato dot ac dot nz)
- * @version $Revision: 4767 $
+ * @version $Revision: 7411 $
  */
 public class XMLBeans 
   extends XMLBasicSerialization {
@@ -107,10 +108,10 @@ public class XMLBeans
   public final static String VAL_OPTIONS = "options";
   
   /** the value of the saver property */
-  public final static String VAL_SAVER = "saver";
+  public final static String VAL_SAVER = "wrappedAlgorithm";
   
   /** the value of the loader property */
-  public final static String VAL_LOADER = "loader";
+  public final static String VAL_LOADER = "wrappedAlgorithm";
   
   /** the value of the text property */
   public final static String VAL_TEXT = "text";
@@ -177,6 +178,9 @@ public class XMLBeans
   
   /** the value of the originalCoords property */
   public final static String VAL_ORIGINALCOORDS = "originalCoords";
+  
+  /** the value of the relationNameForFilename property (Saver) */
+  public final static String VAL_RELATIONNAMEFORFILENAME = "relationNameForFilename";
 
   /** the index in the Vector, where the BeanInstances are stored 
    * (Instances and Connections are stored in a Vector and then serialized) */
@@ -267,7 +271,7 @@ public class XMLBeans
     else if (value == DATATYPE_USERCOMPONENTS)
       m_DataType = value;
     else
-      System.out.println("DataType '" + value + "' is unknown!");
+      System.out.println(Messages.getInstance().getString("XMLBeans_SetDataType_DataType_Text_Front") + value + Messages.getInstance().getString("XMLBeans_SetDataType_DataType_Text_End"));
   }
   
   /**
@@ -334,13 +338,15 @@ public class XMLBeans
     m_Properties.addAllowed(weka.gui.beans.BeanInstance.class, "x");
     m_Properties.addAllowed(weka.gui.beans.BeanInstance.class, "y");
     m_Properties.addAllowed(weka.gui.beans.BeanInstance.class, "bean");
-    m_Properties.addAllowed(weka.gui.beans.Saver.class, "saver");
-    m_Properties.addAllowed(weka.gui.beans.Loader.class, "loader");
+    m_Properties.addAllowed(weka.gui.beans.Saver.class, "wrappedAlgorithm");
+    m_Properties.addAllowed(weka.gui.beans.Loader.class, "wrappedAlgorithm");
+    m_Properties.addAllowed(weka.gui.beans.Saver.class, "relationNameForFilename");
     if (getDataType() == DATATYPE_LAYOUT)
       m_Properties.addAllowed(weka.gui.beans.Loader.class, "beanContext");
     else
       m_Properties.addIgnored(weka.gui.beans.Loader.class, "beanContext");   // TODO: more classes???
     m_Properties.addAllowed(weka.gui.beans.Filter.class, "filter");
+    m_Properties.addAllowed(weka.gui.beans.Associator.class, "associator");
     m_Properties.addAllowed(weka.gui.beans.Classifier.class, "wrappedAlgorithm");
     m_Properties.addAllowed(weka.gui.beans.Clusterer.class, "wrappedAlgorithm");
     m_Properties.addAllowed(weka.gui.beans.Classifier.class, "executionSlots");
@@ -348,6 +354,8 @@ public class XMLBeans
     m_Properties.addAllowed(weka.classifiers.Classifier.class, "debug");
     m_Properties.addAllowed(weka.classifiers.Classifier.class, "options");
     m_Properties.addAllowed(weka.filters.Filter.class, "options");
+    m_Properties.addAllowed(weka.associations.Associator.class, "options");
+    m_Properties.addAllowed(weka.clusterers.Clusterer.class, "options");
     
     m_Properties.addAllowed(weka.core.converters.DatabaseSaver.class, "options");
     m_Properties.addAllowed(weka.core.converters.DatabaseLoader.class, "options");
@@ -410,7 +418,7 @@ public class XMLBeans
         addBeanInstances(((MetaBean) list.get(i)).getBeansInSubFlow());
       }
       else {
-        System.out.println("addBeanInstances does not support Vectors of class '" + list.get(i) + "'!");
+        System.out.println(Messages.getInstance().getString("XMLBeans_SetDataType_AddBeanInstances_Text_Front") + list.get(i) + Messages.getInstance().getString("XMLBeans_SetDataType_AddBeanInstances_Text_End"));
       }
     }
   }
@@ -440,7 +448,7 @@ public class XMLBeans
         break;
         
       default:
-        System.out.println("writePreProcess: data type '" + getDataType() + "' is not recognized!");
+        System.out.println(Messages.getInstance().getString("XMLBeans_WritePreProcess_Text_Front") + getDataType() + Messages.getInstance().getString("XMLBeans_WritePreProcess_Text_End"));
         break;
     }
     
@@ -847,8 +855,9 @@ public class XMLBeans
       else if (name.equals(VAL_BLUE))
         blue = readIntFromXML(child);
       else
-        System.out.println("WARNING: '" + name
-            + "' is not a recognized name for " + node.getAttribute(ATT_NAME) + "!");
+        System.out.println(Messages.getInstance().getString("XMLBeans_ReadColor_Text_First") + name
+            + Messages.getInstance().getString("XMLBeans_ReadColor_Text_Second") + node.getAttribute(ATT_NAME) + 
+            Messages.getInstance().getString("XMLBeans_ReadColor_Text_Third"));
     }
     
     result = new Color(red, green, blue);
@@ -922,8 +931,8 @@ public class XMLBeans
       else if (name.equals(VAL_HEIGHT))
         height = readDoubleFromXML(child);
       else
-        System.out.println("WARNING: '" + name
-            + "' is not a recognized name for " + node.getAttribute(ATT_NAME) + "!");
+        System.out.println(Messages.getInstance().getString("XMLBeans_ReadDimension_Text_First") + name
+            + Messages.getInstance().getString("XMLBeans_ReadDimension_Text_Second") + node.getAttribute(ATT_NAME) + Messages.getInstance().getString("XMLBeans_ReadDimension_Text_Third"));
     }
     
     result = new Dimension();
@@ -1003,8 +1012,8 @@ public class XMLBeans
       else if (name.equals(VAL_SIZE))
         size = readIntFromXML(child);
       else
-        System.out.println("WARNING: '" + name
-            + "' is not a recognized name for " + node.getAttribute(ATT_NAME) + "!");
+        System.out.println(Messages.getInstance().getString("XMLBeans_ReadFont_Text_First") + name
+            + Messages.getInstance().getString("XMLBeans_ReadFont_Text_Second") + node.getAttribute(ATT_NAME) + Messages.getInstance().getString("XMLBeans_ReadFont_Text_Third"));
     }
     
     result = new Font(fontname, style, size);
@@ -1078,8 +1087,9 @@ public class XMLBeans
       else if (name.equals(VAL_Y))
         y = readDoubleFromXML(child);
       else
-        System.out.println("WARNING: '" + name
-            + "' is not a recognized name for " + node.getAttribute(ATT_NAME) + "!");
+        System.out.println(Messages.getInstance().getString("XMLBeans_ReadPoint_Text_First") + name
+            + Messages.getInstance().getString("XMLBeans_ReadPoint_Text_Second") + node.getAttribute(ATT_NAME) 
+            + Messages.getInstance().getString("XMLBeans_ReadPoint_Text_Third"));
     }
     
     result = new Point();
@@ -1148,8 +1158,9 @@ public class XMLBeans
       if (name.equals(VAL_COLOR))
         color = (Color) invokeReadFromXML(child);
       else
-        System.out.println("WARNING: '" + name
-            + "' is not a recognized name for " + node.getAttribute(ATT_NAME) + "!");
+        System.out.println(Messages.getInstance().getString("XMLBeans_ReadColorUIResource_Text_First") + name
+            + Messages.getInstance().getString("XMLBeans_ReadColorUIResource_Text_Second") + node.getAttribute(ATT_NAME)
+            + Messages.getInstance().getString("XMLBeans_ReadColorUIResource_Text_Third"));
     }
     
     result = new ColorUIResource(color);
@@ -1217,8 +1228,9 @@ public class XMLBeans
       if (name.equals(VAL_FONT))
         font = (Font) invokeReadFromXML(child);
       else
-        System.out.println("WARNING: '" + name
-            + "' is not a recognized name for " + node.getAttribute(ATT_NAME) + "!");
+        System.out.println(Messages.getInstance().getString("XMLBeans_ReadFontUIResource_Text_First") + name
+            + Messages.getInstance().getString("XMLBeans_ReadFontUIResource_Text_Second") + node.getAttribute(ATT_NAME)
+            + Messages.getInstance().getString("XMLBeans_ReadFontUIResource_Text_Third"));
     }
     
     result = new FontUIResource(font);
@@ -1312,8 +1324,9 @@ public class XMLBeans
       } else if (name.equals(VAL_BEAN)) {
         bean = invokeReadFromXML(child);
       } else {
-        System.out.println("WARNING: '" + name
-            + "' is not a recognized name for " + node.getAttribute(ATT_NAME) + "!");
+        System.out.println(Messages.getInstance().getString("XMLBeans_ReadBeanInstance_Text_First") + name
+            + Messages.getInstance().getString("XMLBeans_ReadBeanInstance_Text_Second") + node.getAttribute(ATT_NAME)
+            + Messages.getInstance().getString("XMLBeans_ReadBeanInstance_Text_Third"));
       }
     }
     
@@ -1456,8 +1469,9 @@ public class XMLBeans
       else if (name.equals(VAL_HIDDEN))
         hidden = readBooleanFromXML(child);
       else
-        System.out.println("WARNING: '" + name
-            + "' is not a recognized name for " + node.getAttribute(ATT_NAME) + "!");
+        System.out.println(Messages.getInstance().getString("XMLBeans_ReadBeanConnection_Text_First") + name
+            + Messages.getInstance().getString("XMLBeans_ReadBeanConnection_Text_Second") + node.getAttribute(ATT_NAME) 
+            + Messages.getInstance().getString("XMLBeans_ReadBeanConnection_Text_Third"));
     }
 
     // get position of id
@@ -1530,8 +1544,9 @@ public class XMLBeans
     
     saver = (weka.gui.beans.Saver) o;
     node   = addElement(parent, name, saver.getClass().getName(), false);
+    invokeWriteToXML(node, saver.getRelationNameForFilename(), VAL_RELATIONNAMEFORFILENAME);
 
-    invokeWriteToXML(node, saver.getSaver(), VAL_SAVER);
+    invokeWriteToXML(node, saver.getSaverTemplate(), VAL_SAVER);
     
     return node;
   }
@@ -1571,7 +1586,8 @@ public class XMLBeans
       known = false;
 
     if (!known)
-      System.out.println("WARNING: unknown loader class '" + loader.getClass().getName() + "' - cannot retrieve file!");
+      System.out.println(Messages.getInstance().getString("XMLBeans_WriteLoader_Text_First") + loader.getClass().getName() 
+    		  + Messages.getInstance().getString("XMLBeans_WriteLoader_Text_Second"));
 
     Boolean relativeB = null;
     if (loader instanceof weka.core.converters.FileSourcedConverter) {
@@ -1583,7 +1599,12 @@ public class XMLBeans
     if ( (file == null) || (file.isDirectory()) ) {
       invokeWriteToXML(node, "", VAL_FILE);
     } else {
-      String path = (((weka.core.converters.AbstractFileLoader) loader).getUseRelativePath())
+      boolean notAbsolute = 
+        (((weka.core.converters.AbstractFileLoader) loader).getUseRelativePath() ||
+        (loader instanceof EnvironmentHandler 
+            && Environment.containsEnvVariables(file.getPath())));
+      
+      String path = (notAbsolute)
         ? file.getPath()
         : file.getAbsolutePath();
       // Replace any windows file separators with forward slashes (Java under windows can
@@ -1652,19 +1673,18 @@ public class XMLBeans
     // set file only, if it exists
     if (file != null) {
       String tempFile = file;
-      // try and replace any environment variables before we
-      // test for existence
-      try {
-        tempFile = Environment.substitute(file);
-      } catch (Exception ex) {
-        System.out.println(ex.getMessage());
-      }
-      //      fl = new File(file);
-      fl = new File(tempFile);
-      if (fl.exists()) {
+
+      boolean containsEnv = false;
+      containsEnv = Environment.containsEnvVariables(file);
+      
+      fl = new File(file);      
+      // only test for existence if the path does not contain environment vars
+      // (trust that after they are resolved that everything is hunky dory)
+      if (containsEnv || fl.exists()) {
         ((weka.core.converters.AbstractFileLoader) result).setSource(new File(file));
       } else {
-        System.out.println("WARNING: The file '" + tempFile + "' does not exist!");
+        System.out.println(Messages.getInstance().getString("XMLBeans_ReadLoader_Text_Front") + tempFile 
+        		+ Messages.getInstance().getString("XMLBeans_ReadLoader_Text_End"));
       }
     }
     
@@ -1717,7 +1737,8 @@ public class XMLBeans
     }
     
     if (!known)
-      System.out.println("WARNING: unknown saver class '" + saver.getClass().getName() + "' - cannot retrieve file!");
+      System.out.println(Messages.getInstance().getString("XMLBeans_WriteSaver_Text_Front") + saver.getClass().getName() 
+    		  + Messages.getInstance().getString("XMLBeans_WriteSaver_Text_End"));
 
     Boolean relativeB = null;
     if (saver instanceof weka.core.converters.FileSourcedConverter) {
@@ -2026,9 +2047,9 @@ public class XMLBeans
       else if (name.equals(VAL_ORIGINALCOORDS))
         coords = (Vector) invokeReadFromXML(child);
       else if (name.equals(VAL_INPUTS))
-        System.out.println("INFO: '" + name + "' will be restored later.");
+        System.out.println(Messages.getInstance().getString("XMLBeans_ReadMetaBean_Input_Text_Front") + name + Messages.getInstance().getString("XMLBeans_ReadMetaBean_Input_Text_End"));
       else if (name.equals(VAL_OUTPUTS))
-        System.out.println("INFO: '" + name + "' will be restored later.");
+        System.out.println(Messages.getInstance().getString("XMLBeans_ReadMetaBean_Output_Text_Front") + name + Messages.getInstance().getString("XMLBeans_ReadMetaBean_Output_Text_End"));
       else
         readFromXML(result, name, child);
     }
