@@ -102,7 +102,7 @@ import weka.gui.visualize.MatrixPanel;
  * so that previous results are accessible.
  *
  * @author Mark Hall (mhall@cs.waikato.ac.nz)
- * @version $Revision: 7101 $
+ * @version $Revision: 9495 $
  */
 public class AttributeSelectionPanel 
   extends JPanel
@@ -374,7 +374,14 @@ public class AttributeSelectionPanel
 
     m_StartBut.addActionListener(new ActionListener() {
       public void actionPerformed(ActionEvent e) {
-	startAttributeSelection();
+        boolean proceed = true;
+        if (Explorer.m_Memory.memoryIsLow()) {
+          proceed = Explorer.m_Memory.showMemoryIsLow();
+        }
+        
+        if (proceed) {
+          startAttributeSelection();
+        }
       }
     });
     m_StopBut.addActionListener(new ActionListener() {
