@@ -22,17 +22,6 @@
 
 package weka.gui.explorer;
 
-import weka.core.Capabilities;
-import weka.core.Copyright;
-import weka.core.Instances;
-import weka.core.Memory;
-import weka.core.converters.AbstractFileLoader;
-import weka.core.converters.ConverterUtils;
-import weka.gui.LogPanel;
-import weka.gui.Logger;
-import weka.gui.LookAndFeel;
-import weka.gui.WekaTaskMonitor;
-
 import java.awt.BorderLayout;
 import java.awt.Image;
 import java.awt.Toolkit;
@@ -53,15 +42,25 @@ import javax.swing.JPanel;
 import javax.swing.JTabbedPane;
 import javax.swing.event.ChangeEvent;
 
-/** 
- * The main class for the Weka explorer. Lets the user create,
- * open, save, configure, datasets, and perform ML analysis.
- *
+import weka.core.Capabilities;
+import weka.core.Copyright;
+import weka.core.Instances;
+import weka.core.Memory;
+import weka.core.converters.AbstractFileLoader;
+import weka.core.converters.ConverterUtils;
+import weka.gui.LogPanel;
+import weka.gui.Logger;
+import weka.gui.LookAndFeel;
+import weka.gui.WekaTaskMonitor;
+
+/**
+ * The main class for the Weka explorer. Lets the user create, open, save,
+ * configure, datasets, and perform ML analysis.
+ * 
  * @author Len Trigg (trigg@cs.waikato.ac.nz)
- * @version $Revision: 7193 $
+ * @version $Revision: 10438 $
  */
-public class Explorer
-  extends JPanel {
+public class Explorer extends JPanel {
 
   /** for serialization */
   private static final long serialVersionUID = -7674003708867909578L;
@@ -70,49 +69,48 @@ public class Explorer
    * Interface for classes that listen for filter changes.
    * 
    * @author FracPete (fracpete at waikato dot ac dot nz)
-   * @version $Revision: 7193 $
+   * @version $Revision: 10438 $
    */
-  public static interface CapabilitiesFilterChangeListener 
-    extends EventListener {
-    
+  public static interface CapabilitiesFilterChangeListener extends
+    EventListener {
+
     /**
      * method gets called in case of a change event
      * 
-     * @param e		the associated change event
+     * @param e the associated change event
      */
     public void capabilitiesFilterChanged(CapabilitiesFilterChangeEvent e);
   }
 
   /**
-   * This event can be fired in case the capabilities filter got changed 
+   * This event can be fired in case the capabilities filter got changed
    * 
    * @author FracPete (fracpete at waikato dot ac dot nz)
-   * @version $Revision: 7193 $
+   * @version $Revision: 10438 $
    */
-  public static class CapabilitiesFilterChangeEvent
-    extends ChangeEvent {
+  public static class CapabilitiesFilterChangeEvent extends ChangeEvent {
 
     /** for serialization */
     private static final long serialVersionUID = 1194260517270385559L;
-    
+
     /** the capabilities filter */
     protected Capabilities m_Filter;
-    
+
     /**
      * Constructs a GOECapabilitiesFilterChangeEvent object.
      * 
-     * @param source	the Object that is the source of the event
-     * @param filter	the responsible capabilities filter
+     * @param source the Object that is the source of the event
+     * @param filter the responsible capabilities filter
      */
     public CapabilitiesFilterChangeEvent(Object source, Capabilities filter) {
       super(source);
       m_Filter = filter;
     }
-    
+
     /**
      * returns the associated Capabilities filter
      * 
-     * @return		the filter
+     * @return the filter
      */
     public Capabilities getFilter() {
       return m_Filter;
@@ -123,7 +121,7 @@ public class Explorer
    * A common interface for panels to be displayed in the Explorer
    * 
    * @author FracPete (fracpete at waikato dot ac dot nz)
-   * @version $Revision: 7193 $
+   * @version $Revision: 10438 $
    */
   public static interface ExplorerPanel {
 
@@ -131,31 +129,31 @@ public class Explorer
      * Sets the Explorer to use as parent frame (used for sending notifications
      * about changes in the data)
      * 
-     * @param parent	the parent frame
+     * @param parent the parent frame
      */
     public void setExplorer(Explorer parent);
-    
+
     /**
      * returns the parent Explorer frame
      * 
-     * @return		the parent
+     * @return the parent
      */
     public Explorer getExplorer();
-    
+
     /**
      * Tells the panel to use a new set of instances.
-     *
+     * 
      * @param inst a set of Instances
      */
     public void setInstances(Instances inst);
-    
+
     /**
      * Returns the title for the tab in the Explorer
      * 
      * @return the title of this tab
      */
     public String getTabTitle();
-    
+
     /**
      * Returns the tooltip for the tab in the Explorer
      * 
@@ -168,13 +166,13 @@ public class Explorer
    * A common interface for panels in the explorer that can handle logs
    * 
    * @author FracPete (fracpete at waikato dot ac dot nz)
-   * @version $Revision: 7193 $
+   * @version $Revision: 10438 $
    */
   public static interface LogHandler {
-    
+
     /**
      * Sets the Logger to receive informational messages
-     *
+     * 
      * @param newLog the Logger that will now get info messages
      */
     public void setLog(Logger newLog);
@@ -182,65 +180,75 @@ public class Explorer
 
   /** The panel for preprocessing instances */
   protected PreprocessPanel m_PreprocessPanel = new PreprocessPanel();
-  
+
   /** Contains all the additional panels apart from the pre-processing panel */
   protected Vector<ExplorerPanel> m_Panels = new Vector<ExplorerPanel>();
-  
+
   /** The tabbed pane that controls which sub-pane we are working with */
   protected JTabbedPane m_TabbedPane = new JTabbedPane();
-  
+
   /** The panel for log and status messages */
   protected LogPanel m_LogPanel = new LogPanel(new WekaTaskMonitor());
-  
+
   /** the listeners that listen to filter changes */
   protected HashSet<CapabilitiesFilterChangeListener> m_CapabilitiesFilterChangeListeners = new HashSet<CapabilitiesFilterChangeListener>();
-  
+
   /**
    * Creates the experiment environment gui with no initial experiment
    */
   public Explorer() {
-    
-    String date = (new SimpleDateFormat("EEEE, d MMMM yyyy")).format(new Date());
-    m_LogPanel.logMessage(Messages.getInstance().getString("Explorer_LogPanel_LogMessage_Text_First"));
-    m_LogPanel.logMessage(Messages.getInstance().getString("Explorer_LogPanel_LogMessage_Text_Second") + Copyright.getFromYear() + Messages.getInstance().getString("Explorer_LogPanel_LogMessage_Text_Third")
-    		 + Copyright.getToYear() 
-	+ " " + Copyright.getOwner() + ", " + Copyright.getAddress());
-    m_LogPanel.logMessage(Messages.getInstance().getString("Explorer_LogPanel_LogMessage_Text_Fourth") + Copyright.getURL());
-    m_LogPanel.logMessage(Messages.getInstance().getString("Explorer_LogPanel_LogMessage_Text_Fifth") + date);
-    m_LogPanel.statusMessage(Messages.getInstance().getString("Explorer_LogPanel_StatusMessage_Text_First"));
+
+    String date = (new SimpleDateFormat("EEEE, d MMMM yyyy"))
+      .format(new Date());
+    m_LogPanel.logMessage(Messages.getInstance().getString(
+      "Explorer_LogPanel_LogMessage_Text_First"));
+    m_LogPanel.logMessage(Messages.getInstance().getString(
+      "Explorer_LogPanel_LogMessage_Text_Second")
+      + Copyright.getFromYear()
+      + Messages.getInstance().getString(
+        "Explorer_LogPanel_LogMessage_Text_Third")
+      + Copyright.getToYear()
+      + " " + Copyright.getOwner() + ", " + Copyright.getAddress());
+    m_LogPanel.logMessage(Messages.getInstance().getString(
+      "Explorer_LogPanel_LogMessage_Text_Fourth")
+      + Copyright.getURL());
+    m_LogPanel.logMessage(Messages.getInstance().getString(
+      "Explorer_LogPanel_LogMessage_Text_Fifth")
+      + date);
+    m_LogPanel.statusMessage(Messages.getInstance().getString(
+      "Explorer_LogPanel_StatusMessage_Text_First"));
 
     // intialize pre-processpanel
     m_PreprocessPanel.setLog(m_LogPanel);
-    m_TabbedPane.addTab(
-	m_PreprocessPanel.getTabTitle(),
-	null,
-	m_PreprocessPanel,
-	m_PreprocessPanel.getTabTitleToolTip());
-    
+    m_TabbedPane.addTab(m_PreprocessPanel.getTabTitle(), null,
+      m_PreprocessPanel, m_PreprocessPanel.getTabTitleToolTip());
+
     // initialize additional panels
     String[] tabs = ExplorerDefaults.getTabs();
     Hashtable<String, HashSet> tabOptions = new Hashtable<String, HashSet>();
-    for (int i = 0; i < tabs.length; i++) {
+    for (String tab : tabs) {
       try {
-	// determine classname and additional options
-	String[] optionsStr = tabs[i].split(":");
-	String classname = optionsStr[0];
-	HashSet options = new HashSet();
-	tabOptions.put(classname, options);
-	for (int n = 1; n < optionsStr.length; n++)
-	  options.add(optionsStr[n]);
-	  
-	// setup panel
-	ExplorerPanel panel = (ExplorerPanel) Class.forName(classname).newInstance();
-	panel.setExplorer(this);
-	m_Panels.add(panel);
-	if (panel instanceof LogHandler)
-	  ((LogHandler) panel).setLog(m_LogPanel);
-	m_TabbedPane.addTab(
-	    panel.getTabTitle(), null, (JPanel) panel, panel.getTabTitleToolTip());
-      }
-      catch (Exception e) {
-	e.printStackTrace();
+        // determine classname and additional options
+        String[] optionsStr = tab.split(":");
+        String classname = optionsStr[0];
+        HashSet options = new HashSet();
+        tabOptions.put(classname, options);
+        for (int n = 1; n < optionsStr.length; n++) {
+          options.add(optionsStr[n]);
+        }
+
+        // setup panel
+        ExplorerPanel panel = (ExplorerPanel) Class.forName(classname)
+          .newInstance();
+        panel.setExplorer(this);
+        m_Panels.add(panel);
+        if (panel instanceof LogHandler) {
+          ((LogHandler) panel).setLog(m_LogPanel);
+        }
+        m_TabbedPane.addTab(panel.getTabTitle(), null, (JPanel) panel,
+          panel.getTabTitleToolTip());
+      } catch (Exception e) {
+        e.printStackTrace();
       }
     }
 
@@ -253,11 +261,12 @@ public class Explorer
 
     // setup notification for dataset changes
     m_PreprocessPanel.addPropertyChangeListener(new PropertyChangeListener() {
+      @Override
       public void propertyChange(PropertyChangeEvent e) {
-	for (int i = 0; i < m_Panels.size(); i++) {
-	   m_Panels.get(i).setInstances(m_PreprocessPanel.getInstances());
-	   m_TabbedPane.setEnabledAt(i + 1, true);
-	}
+        for (int i = 0; i < m_Panels.size(); i++) {
+          m_Panels.get(i).setInstances(m_PreprocessPanel.getInstances());
+          m_TabbedPane.setEnabledAt(i + 1, true);
+        }
       }
     });
 
@@ -265,8 +274,10 @@ public class Explorer
     m_PreprocessPanel.setExplorer(this);
     addCapabilitiesFilterListener(m_PreprocessPanel);
     for (int i = 0; i < m_Panels.size(); i++) {
-      if (m_Panels.get(i) instanceof CapabilitiesFilterChangeListener)
-	addCapabilitiesFilterListener((CapabilitiesFilterChangeListener) m_Panels.get(i));
+      if (m_Panels.get(i) instanceof CapabilitiesFilterChangeListener) {
+        addCapabilitiesFilterListener((CapabilitiesFilterChangeListener) m_Panels
+          .get(i));
+      }
     }
 
     // add components to layout
@@ -274,41 +285,41 @@ public class Explorer
     add(m_TabbedPane, BorderLayout.CENTER);
     add(m_LogPanel, BorderLayout.SOUTH);
   }
-  
+
   /**
    * returns all the panels, apart from the PreprocessPanel
    * 
-   * @return		the currently displayed panels w/o PreprocessPanel
+   * @return the currently displayed panels w/o PreprocessPanel
    */
   public Vector<ExplorerPanel> getPanels() {
     return m_Panels;
   }
-  
+
   /**
-   * returns the instance of the PreprocessPanel being used in this instance
-   * of the Explorer
+   * returns the instance of the PreprocessPanel being used in this instance of
+   * the Explorer
    * 
-   * @return		the panel
+   * @return the panel
    */
   public PreprocessPanel getPreprocessPanel() {
     return m_PreprocessPanel;
   }
-  
+
   /**
    * returns the tabbed pane of the Explorer
    * 
-   * @return		the tabbed pane
+   * @return the tabbed pane
    */
   public JTabbedPane getTabbedPane() {
     return m_TabbedPane;
   }
-  
+
   /**
    * adds the listener to the list of objects that listen for changes of the
    * CapabilitiesFilter
    * 
-   * @param l		the listener to add
-   * @see		#m_CapabilitiesFilterChangeListeners
+   * @param l the listener to add
+   * @see #m_CapabilitiesFilterChangeListeners
    */
   public void addCapabilitiesFilterListener(CapabilitiesFilterChangeListener l) {
     m_CapabilitiesFilterChangeListeners.add(l);
@@ -317,54 +328,61 @@ public class Explorer
   /**
    * Removes the specified listener from the set of listeners if it is present.
    * 
-   * @param l		the listener to remove
-   * @return		true if the listener was registered
+   * @param l the listener to remove
+   * @return true if the listener was registered
    */
-  public boolean removeCapabilitiesFilterListener(CapabilitiesFilterChangeListener l) {
+  public boolean removeCapabilitiesFilterListener(
+    CapabilitiesFilterChangeListener l) {
     return m_CapabilitiesFilterChangeListeners.remove(l);
   }
-  
+
   /**
    * notifies all the listeners of a change
    * 
-   * @param filter	the affected filter
+   * @param filter the affected filter
    */
   public void notifyCapabilitiesFilterListener(Capabilities filter) {
-    for (CapabilitiesFilterChangeListener l: m_CapabilitiesFilterChangeListeners) {
-      if (l == this)
-	continue;
-      l.capabilitiesFilterChanged(new CapabilitiesFilterChangeEvent(this, filter));
+    for (CapabilitiesFilterChangeListener l : m_CapabilitiesFilterChangeListeners) {
+      if (l == this) {
+        continue;
+      }
+      l.capabilitiesFilterChanged(new CapabilitiesFilterChangeEvent(this,
+        filter));
     }
   }
-  
-  /** variable for the Explorer class which would be set to null by the memory 
-      monitoring thread to free up some memory if we running out of memory
+
+  /**
+   * variable for the Explorer class which would be set to null by the memory
+   * monitoring thread to free up some memory if we running out of memory
    */
   private static Explorer m_explorer;
 
   /** for monitoring the Memory consumption */
-  private static Memory m_Memory = new Memory(true);
+  protected static Memory m_Memory = new Memory(true);
 
   /**
    * Tests out the explorer environment.
-   *
+   * 
    * @param args ignored.
    */
-  public static void main(String [] args) {
+  public static void main(String[] args) {
+
+    weka.core.logging.Logger.log(weka.core.logging.Logger.Level.INFO, Messages
+      .getInstance().getString("Explorer_Main_Logger_Text"));
 
-    weka.core.logging.Logger.log(weka.core.logging.Logger.Level.INFO, Messages.getInstance().getString("Explorer_Main_Logger_Text"));
-    
     LookAndFeel.setLookAndFeel();
-    
+
     try {
       // uncomment to disable the memory management:
-      //m_Memory.setEnabled(false);
+      // m_Memory.setEnabled(false);
 
       m_explorer = new Explorer();
-      final JFrame jf = new JFrame(Messages.getInstance().getString("Explorer_Main_JFrame_Text"));
+      final JFrame jf = new JFrame(Messages.getInstance().getString(
+        "Explorer_Main_JFrame_Text"));
       jf.getContentPane().setLayout(new BorderLayout());
       jf.getContentPane().add(m_explorer, BorderLayout.CENTER);
       jf.addWindowListener(new WindowAdapter() {
+        @Override
         public void windowClosing(WindowEvent e) {
           jf.dispose();
           System.exit(0);
@@ -373,43 +391,46 @@ public class Explorer
       jf.pack();
       jf.setSize(800, 600);
       jf.setVisible(true);
-      Image icon = Toolkit.getDefaultToolkit().
-        getImage(m_explorer.getClass().getClassLoader().getResource("weka/gui/weka_icon_new_48.png"));
+      Image icon = Toolkit.getDefaultToolkit().getImage(
+        m_explorer.getClass().getClassLoader()
+          .getResource("weka/gui/weka_icon_new_48.png"));
       jf.setIconImage(icon);
 
       if (args.length == 1) {
-        System.err.println(Messages.getInstance().getString("Explorer_Main_Run_Error_Text") + args[0]);
+        System.err.println(Messages.getInstance().getString(
+          "Explorer_Main_Run_Error_Text")
+          + args[0]);
         AbstractFileLoader loader = ConverterUtils.getLoaderForFile(args[0]);
-	loader.setFile(new File(args[0]));
+        loader.setFile(new File(args[0]));
         m_explorer.m_PreprocessPanel.setInstancesFromFile(loader);
       }
 
       Thread memMonitor = new Thread() {
+        @Override
         public void run() {
-          while(true) {
-            try {
-              //System.out.println("Before sleeping.");
-              this.sleep(4000);
+          while (true) {
+            // try {
+            // //System.out.println("Before sleeping.");
+            // this.sleep(4000);
 
+            // System.gc();
+
+            if (m_Memory.isOutOfMemory()) {
+              // clean up
+              jf.dispose();
+              m_explorer = null;
               System.gc();
 
-              if (m_Memory.isOutOfMemory()) {
-                // clean up
-                jf.dispose();
-                m_explorer = null;
-                System.gc();
+              // display error
+              System.err.println(Messages.getInstance().getString(
+                "Explorer_Main_Run_Error_Text_First"));
+              m_Memory.showOutOfMemory();
+              System.err.println(Messages.getInstance().getString(
+                "Explorer_Main_Run_Error_Text_Second"));
+              System.exit(-1);
+            }
 
-                // stop threads
-                m_Memory.stopThreads();
-
-                // display error
-                System.err.println(Messages.getInstance().getString("Explorer_Main_Run_Error_Text_First"));
-                m_Memory.showOutOfMemory();
-                System.err.println(Messages.getInstance().getString("Explorer_Main_Run_Error_Text_Second"));
-                System.exit(-1);
-              }
-
-            } catch(InterruptedException ex) { ex.printStackTrace(); }
+            // } catch(InterruptedException ex) { ex.printStackTrace(); }
           }
         }
       };
