@@ -29,6 +29,7 @@ import weka.gui.ExtensionFileFilter;
 
 import java.awt.BorderLayout;
 import java.awt.Color;
+import java.awt.Dialog.ModalityType;
 import java.awt.Dimension;
 import java.awt.Graphics;
 import java.awt.GridBagConstraints;
@@ -64,18 +65,18 @@ import javax.swing.JTextField;
 import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
 
-/** 
+/**
  * This panel displays a plot matrix of the user selected attributes
- * of a given data set. 
- * 
- * The datapoints are coloured using a discrete colouring set if the 
+ * of a given data set.
+ *
+ * The datapoints are coloured using a discrete colouring set if the
  * user has selected a nominal attribute for colouring. If the user
  * has selected a numeric attribute then the datapoints are coloured
  * using a colour spectrum ranging from blue to red (low values to
  * high). Datapoints missing a class value are displayed in black.
- * 
+ *
  * @author Ashraf M. Kibriya (amk14@cs.waikato.ac.nz)
- * @version $Revision: 7059 $
+ * @version $Revision: 7899 $
  */
 public class MatrixPanel
   extends JPanel{
@@ -95,7 +96,7 @@ public class MatrixPanel
 
   /** Split pane for splitting the matrix and the buttons and bars */
   protected JSplitPane jp;
-  /** The button that updates the display to reflect the changes made by the user. 
+  /** The button that updates the display to reflect the changes made by the user.
       E.g. changed attribute set for the matrix    */
   protected JButton m_updateBt = new JButton(Messages.getInstance().getString("MatrixPanel_UpdateBt_JButton_Text"));
 
@@ -114,21 +115,21 @@ public class MatrixPanel
   /** The combo box to allow user to select the colouring attribute */
   protected JComboBox m_classAttrib = new JComboBox();
 
-  /** The slider to adjust the size of the cells in the matrix  */  
+  /** The slider to adjust the size of the cells in the matrix  */
   protected JSlider m_plotSize = new JSlider(50, 500, 100);
 
-  /** The slider to adjust the size of the datapoints  */  
+  /** The slider to adjust the size of the datapoints  */
   protected JSlider m_pointSize = new JSlider(1, 10, 1);
 
-  /** The slider to add jitter to the plots */  
-  protected JSlider m_jitter = new JSlider(0, 20, 0); 
+  /** The slider to add jitter to the plots */
+  protected JSlider m_jitter = new JSlider(0, 20, 0);
 
   /** For adding random jitter */
   private Random rnd = new Random();
-    
+
   /** Array containing precalculated jitter values */
   private int jitterVals[][];
- 
+
   /** This stores the size of the datapoint */
   private int datapointSize=1;
 
@@ -140,7 +141,7 @@ public class MatrixPanel
 
   /** Random seed for random subsample */
   protected JTextField m_rseed = new JTextField(5);
- 
+
   /** Displays the current size beside the slider bar for cell size */
   private final JLabel m_plotSizeLb = new JLabel(Messages.getInstance().getString("MatrixPanel_PlotSizeLb_JLabel_Text"));
 
@@ -156,16 +157,16 @@ public class MatrixPanel
   /** This is a local array cache for all the instance values for faster rendering */
   private int [][] m_points;
 
-  /** This is an array cache for the colour of each of the instances depending on the 
-      colouring attribute. If the colouring attribute is nominal then it contains the 
+  /** This is an array cache for the colour of each of the instances depending on the
+      colouring attribute. If the colouring attribute is nominal then it contains the
       index of the colour in our colour list. Otherwise, for numeric colouring attribute,
       it contains the precalculated red component for each instance's colour */
   private int [] m_pointColors;
 
-  /** Contains true for each attribute value (only the selected attributes+class attribute) 
+  /** Contains true for each attribute value (only the selected attributes+class attribute)
       that is  missing, for each instance.
-      m_missing[i][j] == true if m_selectedAttribs[j] is missing in instance i. 
-      m_missing[i][m_missing[].length-1] == true  if class value is missing in instance i. */ 
+      m_missing[i][j] == true if m_selectedAttribs[j] is missing in instance i.
+      m_missing[i][m_missing[].length-1] == true  if class value is missing in instance i. */
   private boolean [][] m_missing;
 
   /** This array contains for the classAttribute: <br>
@@ -204,7 +205,7 @@ public class MatrixPanel
 
 
 
-  /** 
+  /**
    * Constructor
    */
   public MatrixPanel() {
@@ -213,17 +214,17 @@ public class MatrixPanel
     /** Setting up GUI **/
     m_selAttrib.addActionListener( new ActionListener() {
 	public void actionPerformed(ActionEvent ae) {
-	  final JDialog jd = new JDialog((JFrame) MatrixPanel.this.getTopLevelAncestor(), 
+	  final JDialog jd = new JDialog((JFrame) MatrixPanel.this.getTopLevelAncestor(),
 			  Messages.getInstance().getString("MatrixPanel_Jd_JDialog_Text"),
-					 true);
+			  ModalityType.DOCUMENT_MODAL);
 
 	  JPanel jp = new JPanel();
 	  JScrollPane js = new JScrollPane(m_attribList);
 	  JButton okBt = new JButton(Messages.getInstance().getString("MatrixPanel_OkBt_JButton_Text"));
 	  JButton cancelBt = new JButton(Messages.getInstance().getString("MatrixPanel_CancelBt_JButton_Text"));
 	  final int [] savedSelection = m_attribList.getSelectedIndices();
-					
-	  okBt.addActionListener( new ActionListener() {	
+
+	  okBt.addActionListener( new ActionListener() {
 	      public void actionPerformed(ActionEvent e) {
 		jd.dispose(); }
 	    } );
@@ -241,46 +242,46 @@ public class MatrixPanel
 	  jp.add(okBt);
 	  jp.add(cancelBt);
 
-	  jd.getContentPane().add(js, BorderLayout.CENTER); 
+	  jd.getContentPane().add(js, BorderLayout.CENTER);
 	  jd.getContentPane().add(jp, BorderLayout.SOUTH);
 
 	  if(js.getPreferredSize().width < 200)
 	    jd.setSize( 250, 250 );
 	  else
 	    jd.setSize( (int) js.getPreferredSize().width+10, 250);
-					
+
 	  jd.setLocation( m_selAttrib.getLocationOnScreen().x,
 			  m_selAttrib.getLocationOnScreen().y-jd.getHeight() );
 	  jd.setVisible(true);
 	}
       });
-      
+
     m_updateBt.addActionListener( new ActionListener() {
 	public void actionPerformed(ActionEvent e) {
 	    //m_selectedAttribs = m_attribList.getSelectedIndices();
 	  initInternalFields();
-					
+
 	  Plot a = m_plotsPanel;
-	  a.setCellSize( m_plotSize.getValue() );					
-	  Dimension d = new Dimension((m_selectedAttribs.length)*(a.cellSize+a.extpad)+2, 
+	  a.setCellSize( m_plotSize.getValue() );
+	  Dimension d = new Dimension((m_selectedAttribs.length)*(a.cellSize+a.extpad)+2,
 				      (m_selectedAttribs.length)*(a.cellSize+a.extpad)+2
 				     );
 	  //System.out.println("Size: "+a.cellSize+" Extpad: "+
 	  //		   a.extpad+" selected: "+
-	  //		   m_selectedAttribs.length+' '+d); 
+	  //		   m_selectedAttribs.length+' '+d);
 	  a.setPreferredSize(d);
 	  a.setSize( a.getPreferredSize() );
 	  a.setJitter( m_jitter.getValue() );
-					
+
 	  m_js.revalidate();
 	  m_cp.setColours(m_colorList);
 	  m_cp.setCindex(m_classIndex);
-					
+
 	  repaint();
 	}
       });
     m_updateBt.setPreferredSize( m_selAttrib.getPreferredSize() );
-      
+
     m_plotSize.addChangeListener( new ChangeListener() {
 	public void stateChanged(ChangeEvent ce) {
 	  m_plotSizeLb.setText(Messages.getInstance().getString("MatrixPanel_StateChanged_PlotSizeLb_Text_First") + m_plotSize.getValue() + Messages.getInstance().getString("MatrixPanel_StateChanged_PlotSizeLb_Text_Second"));
@@ -288,7 +289,7 @@ public class MatrixPanel
 	  m_jitter.setMaximum( m_plotSize.getValue()/5 ); //20% of cell Size
 	}
       });
- 
+
     m_pointSize.addChangeListener( new ChangeListener() {
 	public void stateChanged(ChangeEvent ce) {
 	  m_pointSizeLb.setText(Messages.getInstance().getString("MatrixPanel_StateChanged_PointSizeLb_Text_First") + m_pointSize.getValue() + Messages.getInstance().getString("MatrixPanel_StateChanged_PointSizeLb_Text_Second"));
@@ -296,8 +297,8 @@ public class MatrixPanel
 	  datapointSize = m_pointSize.getValue();
 	}
       });
- 
-    m_resampleBt.addActionListener( new ActionListener() { 
+
+    m_resampleBt.addActionListener( new ActionListener() {
 	public void actionPerformed(ActionEvent e) {
 	  JLabel rseedLb = new JLabel(Messages.getInstance().getString("MatrixPanel_ActionPerformed_RseedLb_JLabel_Text"));
 	  JTextField rseedTxt = m_rseed;
@@ -307,26 +308,26 @@ public class MatrixPanel
 	  percentTxt.setText( m_resamplePercent.getText() );
 	  JButton doneBt = new JButton(Messages.getInstance().getString("MatrixPanel_ActionPerformed_DoneBt_JButton_Text"));
 
-	  final JDialog jd = new JDialog((JFrame) MatrixPanel.this.getTopLevelAncestor(), 
+	  final JDialog jd = new JDialog((JFrame) MatrixPanel.this.getTopLevelAncestor(),
 			  Messages.getInstance().getString("MatrixPanel_ActionPerformed_Jd_JDialog_Text"),
-					 true) {
+			  ModalityType.DOCUMENT_MODAL) {
 	      private static final long serialVersionUID = -269823533147146296L;
-	      
-	      public void dispose() { 
+
+	      public void dispose() {
 		m_resamplePercent.setText(percentTxt.getText());
 		super.dispose();
-	      } 
+	      }
 	    };
 	  jd.setDefaultCloseOperation( JDialog.DISPOSE_ON_CLOSE );
-			       
-	  doneBt.addActionListener( new ActionListener(){ 
+
+	  doneBt.addActionListener( new ActionListener(){
 	      public void actionPerformed(ActionEvent ae) {
-		jd.dispose();  
+		jd.dispose();
 	      }
 	    });
 	  GridBagLayout gbl = new GridBagLayout();
 	  GridBagConstraints gbc = new GridBagConstraints();
-	  JPanel p1 = new JPanel( gbl );		
+	  JPanel p1 = new JPanel( gbl );
 	  gbc.anchor = GridBagConstraints.WEST; gbc.fill = GridBagConstraints.HORIZONTAL;
 	  gbc.insets = new Insets(0,2,2,2);
 	  gbc.gridwidth = GridBagConstraints.RELATIVE;
@@ -347,7 +348,7 @@ public class MatrixPanel
 	  p3.add(p1, gbc);
 	  gbc.insets = new Insets(8,4,8,4);
 	  p3.add(doneBt, gbc);
-					   
+
 	  jd.getContentPane().setLayout( new BorderLayout() );
 	  jd.getContentPane().add(p3, BorderLayout.NORTH);
 	  jd.pack();
@@ -362,7 +363,7 @@ public class MatrixPanel
     final JPanel p3 = new JPanel( new GridBagLayout() ); //this has update and select buttons
     final JPanel p4 = new JPanel( new GridBagLayout() ); //this has the slider bars and combobox
     GridBagConstraints gbc = new GridBagConstraints();
-     
+
     m_plotLBSizeD = m_plotSizeLb.getPreferredSize();
     m_pointLBSizeD = m_pointSizeLb.getPreferredSize();
     m_pointSizeLb.setText(Messages.getInstance().getString("MatrixPanel_ActionPerformed_PointSizeLb_Text"));
@@ -384,7 +385,7 @@ public class MatrixPanel
     gbc.weightx=1; gbc.gridwidth = GridBagConstraints.REMAINDER;
     p4.add(m_jitter, gbc);
     p4.add(m_classAttrib, gbc);
-      
+
     gbc.gridwidth = GridBagConstraints.REMAINDER;
     gbc.weightx=1;
     gbc.fill = GridBagConstraints.NONE;
@@ -397,7 +398,7 @@ public class MatrixPanel
     p3.add(m_resampleBt, gbc);
     gbc.gridwidth = GridBagConstraints.REMAINDER;
     p3.add(m_resamplePercent, gbc);
-    
+
     p2.setBorder(BorderFactory.createTitledBorder(Messages.getInstance().getString("MatrixPanel_ActionPerformed_P2_BorderFactoryCreateTitledBorder_Text")));
     p2.add(m_cp, BorderLayout.SOUTH);
 
@@ -428,13 +429,13 @@ public class MatrixPanel
     /** Setting up the initial color list **/
     for(int i=0; i<m_defaultColors.length-1; i++)
       m_colorList.addElement(m_defaultColors[i]);
-      
+
     /** Initializing internal fields and components **/
     m_selectedAttribs = m_attribList.getSelectedIndices();
     m_plotsPanel = new Plot();
     m_plotsPanel.setLayout(null);
     m_js.getHorizontalScrollBar().setUnitIncrement( 10 );
-    m_js.getVerticalScrollBar().setUnitIncrement( 10 ); 
+    m_js.getVerticalScrollBar().setUnitIncrement( 10 );
     m_js.setViewportView( m_plotsPanel );
     m_js.setColumnHeaderView( m_plotsPanel.getColHeader() );
     m_js.setRowHeaderView( m_plotsPanel.getRowHeader() );
@@ -450,7 +451,7 @@ public class MatrixPanel
 
 
 
-  /** Initializes internal data fields, i.e. data values, type, missing and color cache arrays 
+  /** Initializes internal data fields, i.e. data values, type, missing and color cache arrays
    */
   public void initInternalFields() {
     Instances inst = m_data;
@@ -462,40 +463,40 @@ public class MatrixPanel
     if(Double.parseDouble(m_resamplePercent.getText())<100) {
         inst = new Instances(m_data, 0, m_data.numInstances());
         inst.randomize( new Random(Integer.parseInt(m_rseed.getText())) );
-        
+
         //System.err.println("gettingPercent: " +
         //                   Math.round(
         //                     Double.parseDouble(m_resamplePercent.getText())
         //                     / 100D * m_data.numInstances()
         //                             )
         //                  );
-        
-        inst = new Instances(inst, 
+
+        inst = new Instances(inst,
                  0,
                  (int)Math.round(Double.parseDouble(m_resamplePercent.getText())
                  / 100D*inst.numInstances())
                             );
     }
-    
+
     m_points = new int[inst.numInstances()][m_selectedAttribs.length]; //changed
     m_pointColors = new int[inst.numInstances()];
     m_missing = new boolean[inst.numInstances()][m_selectedAttribs.length+1]; //changed
     m_type = new int[2]; //[m_selectedAttribs.length]; //changed
     jitterVals = new int[inst.numInstances()][2];
-      
+
     /** Setting up the color list for non-numeric attribute as well as jittervals**/
     if(!(inst.attribute(m_classIndex).isNumeric())) {
-	  
+
       for(int i=m_colorList.size(); i<inst.attribute(m_classIndex).numValues()+1; i++) {
 	Color pc = m_defaultColors[i % 10];
 	int ija =  i / 10;
-	ija *= 2; 
+	ija *= 2;
 	for (int j=0;j<ija;j++) {
 	    pc = pc.darker();
 	}
 	m_colorList.addElement(pc);
       }
-	  
+
       for(int i=0; i<inst.numInstances(); i++) {
 	//set to black for missing class value which is last colour is default list
 	if(inst.instance(i).isMissing(m_classIndex))
@@ -507,7 +508,7 @@ public class MatrixPanel
 	  - m_jitter.getValue()/2;
 	jitterVals[i][1] = rnd.nextInt(m_jitter.getValue()+1)
 	  - m_jitter.getValue()/2;
-	      
+
       }
     }
     /** Setting up color variations for numeric attribute as well as jittervals **/
@@ -518,7 +519,7 @@ public class MatrixPanel
 	  break;
 	}
       }
-	  
+
       for(int i=1; i<inst.numInstances(); i++) {
 	if(!(inst.instance(i).isMissing(m_classIndex))) {
 	  if(minC > inst.instance(i).value(m_classIndex))
@@ -527,7 +528,7 @@ public class MatrixPanel
 	    maxC = inst.instance(i).value(m_classIndex);
 	}
       }
-	  
+
       for(int i=0; i<inst.numInstances(); i++) {
 	double r = (inst.instance(i).value(m_classIndex) - minC) / (maxC - minC);
 	r = (r * 240) + 15;
@@ -587,7 +588,7 @@ public class MatrixPanel
 	  //m_type[0][j] = m_type[1][j] = 0;
 	for(int i=0; i<inst.numInstances(); i++) {
 	  m_points[i][j] = (int) Math.round((inst.instance(i).value(m_selectedAttribs[j])
-					     -min[j])*ratio[j]);	
+					     -min[j])*ratio[j]);
 	  if(inst.instance(i).isMissing(m_selectedAttribs[j])) {
 	    m_missing[i][j] = true;    //represents missing value
 	    if(m_selectedAttribs[j]==m_classIndex) {
@@ -615,8 +616,8 @@ public class MatrixPanel
     m_cp.setColours(m_colorList);
   }
 
-  /** Sets up the UI's attributes lists 
-   */  
+  /** Sets up the UI's attributes lists
+   */
   public void setupAttribLists() {
     String [] tempAttribNames = new String[m_data.numAttributes()];
     String type;
@@ -653,11 +654,11 @@ public class MatrixPanel
     m_attribList.setSelectionInterval(0, tempAttribNames.length-1);
   }
 
-  /** Calculates the percentage to resample 
+  /** Calculates the percentage to resample
    */
   public void setPercent() {
     if(m_data.numInstances() > 700) {
-      double percnt = 500D/m_data.numInstances()*100;     
+      double percnt = 500D/m_data.numInstances()*100;
       percnt *= 100;
       percnt = Math.round(percnt);
       percnt /= 100;
@@ -695,13 +696,13 @@ public class MatrixPanel
     Instances data = null;
     try {
       if(args.length==1)
-	data = new Instances( new BufferedReader( new FileReader(args[0])) ); 
+	data = new Instances( new BufferedReader( new FileReader(args[0])) );
       else {
-	System.out.println(Messages.getInstance().getString("MatrixPanel_Main_Text")); 
+	System.out.println(Messages.getInstance().getString("MatrixPanel_Main_Text"));
 	System.exit(-1);
       }
     } catch(IOException ex) { ex.printStackTrace(); System.exit(-1); }
-     
+
     final MatrixPanel mp = new MatrixPanel();
     mp.setInstances(data);
     setBt.addActionListener( new ActionListener() {
@@ -710,7 +711,7 @@ public class MatrixPanel
 	  ExtensionFileFilter myfilter = new ExtensionFileFilter(Messages.getInstance().getString("MatrixPanel_Main_ActionPerformed_ExtensionFileFilter_Text_First"), Messages.getInstance().getString("MatrixPanel_Main_ActionPerformed_ExtensionFileFilter_Text_Second"));
 	  chooser.setFileFilter(myfilter);
 	  int returnVal = chooser.showOpenDialog(jf);
-		  
+
 	  if(returnVal == JFileChooser.APPROVE_OPTION)
 	    {
 	      try{
@@ -738,7 +739,7 @@ public class MatrixPanel
     jf.repaint();
   }
 
-  
+
   /**
      Internal class responsible for displaying the actual matrix
      Requires the internal data fields of the parent class to be properly initialized
@@ -749,7 +750,7 @@ public class MatrixPanel
     implements MouseMotionListener, MouseListener {
 
     /** for serialization */
-    private static final long serialVersionUID = -1721245738439420882L;    
+    private static final long serialVersionUID = -1721245738439420882L;
 
     int extpad=3, intpad=4, cellSize=100, cellRange=100, lastx=0, lasty=0, jitter=0;
     java.awt.Rectangle r;
@@ -758,7 +759,7 @@ public class MatrixPanel
     JPanel jPlColHeader, jPlRowHeader;
 
 
-    /** Constructor 
+    /** Constructor
      */
     public Plot() {
       super();
@@ -770,7 +771,7 @@ public class MatrixPanel
 
     /** Initializes the internal fields */
     public void initialize() {
-      lastxpos = lastypos = 0;	  
+      lastxpos = lastypos = 0;
       cellRange = cellSize; cellSize = cellRange + 2*intpad;
 
       jPlColHeader = new JPanel() {
@@ -783,11 +784,11 @@ public class MatrixPanel
           g.setFont( f );
           fm = g.getFontMetrics();
           int xpos = 0, ypos = 0, attribWidth=0;
-          
+
           g.setColor(fontColor);
           xpos = extpad;
           ypos=extpad+fm.getHeight();
-          
+
           for(int i=0; i<m_selectedAttribs.length; i++) {
             if( xpos+cellSize < r.x)
             { xpos += cellSize+extpad; continue; }
@@ -803,7 +804,7 @@ public class MatrixPanel
           }
           fm = null; r=null;
         }
-        
+
         public Dimension getPreferredSize() {
           fm = this.getFontMetrics(this.getFont());
           return new Dimension( m_selectedAttribs.length*(cellSize+extpad),
@@ -813,7 +814,7 @@ public class MatrixPanel
 
       jPlRowHeader = new JPanel() {
 	private static final long serialVersionUID = 8474957069309552844L;
-	
+
         java.awt.Rectangle r;
         public void paint(Graphics g) {
           r = g.getClipBounds();
@@ -822,11 +823,11 @@ public class MatrixPanel
           g.setFont( f );
           fm = g.getFontMetrics();
           int xpos = 0, ypos = 0;
-          
+
           g.setColor(fontColor);
           xpos = extpad;
           ypos=extpad;
-          
+
           for(int j=m_selectedAttribs.length-1; j>=0; j--) {
             if( ypos+cellSize < r.y )
             { ypos += cellSize+extpad;  continue; }
@@ -840,7 +841,7 @@ public class MatrixPanel
           }
           r=null;
         }
-        
+
         public Dimension getPreferredSize() {
           return new Dimension( 100+extpad,
           m_selectedAttribs.length*(cellSize+extpad)
@@ -850,7 +851,7 @@ public class MatrixPanel
       jPlColHeader.setFont(f);
       jPlRowHeader.setFont(f);
       this.setFont(f);
-    }      
+    }
 
     public JPanel getRowHeader() {
 	  return jPlRowHeader;
@@ -893,7 +894,7 @@ public class MatrixPanel
 
     public void mouseClicked(MouseEvent e) {
       int i=0, j=0, found=0;
-	  
+
       int xpos=extpad, ypos=extpad;
       for(j=m_selectedAttribs.length-1; j>=0; j--) {
 	for(i=0; i<m_selectedAttribs.length; i++) {
@@ -926,7 +927,7 @@ public class MatrixPanel
       jf.getContentPane().add(vp);
       jf.setSize(800,600);
       jf.setVisible(true);
-    } 
+    }
 
     public void mouseEntered(MouseEvent e){ }
     public void mouseExited(MouseEvent e){ }
@@ -938,7 +939,7 @@ public class MatrixPanel
     public void setJitter(int newjitter) {
       jitter = newjitter;
     }
-      
+
     /** sets the new size for the plots
      */
     public void setCellSize(int newCellSize) {
@@ -951,7 +952,7 @@ public class MatrixPanel
     */
     public String getToolTipText(MouseEvent event) {
       int xpos=extpad, ypos=extpad;
-	  
+
       for(int j=m_selectedAttribs.length-1; j>=0; j--) {
 	for(int i=0; i<m_selectedAttribs.length; i++) {
 	  if(event.getX()>=xpos && event.getX()<=xpos+cellSize+extpad)
@@ -977,9 +978,9 @@ public class MatrixPanel
       g.setColor(Color.white);
       g.fillRect(xpos, ypos, cellSize, cellSize);
       for(int i=0; i<m_points.length; i++) {
-        
+
         if( !(m_missing[i][yattrib] || m_missing[i][xattrib]) ) {
-          
+
           if(m_type[0]==0)
             if(m_missing[i][m_missing[0].length-1])
               g.setColor(m_defaultColors[m_defaultColors.length-1]);
@@ -987,7 +988,7 @@ public class MatrixPanel
               g.setColor( new Color(m_pointColors[i],150,(255-m_pointColors[i])) );
           else
             g.setColor((Color)m_colorList.elementAt(m_pointColors[i]));
-          
+
           if(m_points[i][xattrib]+jitterVals[i][0]<0 || m_points[i][xattrib]+jitterVals[i][0]>cellRange)
             if(cellRange-m_points[i][yattrib]+jitterVals[i][1]<0 || cellRange-m_points[i][yattrib]+jitterVals[i][1]>cellRange) {
               //both x and y out of range don't add jitter
@@ -1017,24 +1018,24 @@ public class MatrixPanel
       }
       g.setColor( fontColor );
     }
-    
+
 
     /**
        Paints the matrix of plots in the current visible region
     */
     public void paintME(Graphics g) {
       r = g.getClipBounds();
-      
+
       g.setColor( this.getBackground() );
       g.fillRect(r.x, r.y, r.width, r.height);
       g.setColor( fontColor );
-      
+
       int xpos = 0, ypos = 0;
-      
+
       xpos = extpad;
       ypos=extpad;
-      
-      
+
+
       for(int j=m_selectedAttribs.length-1; j>=0; j--) {
         if( ypos+cellSize < r.y )
         { ypos += cellSize+extpad;  continue; }
@@ -1055,7 +1056,7 @@ public class MatrixPanel
         ypos += cellSize+extpad;
       }
     }
-      
+
     /** paints this JPanel (PlotsPanel)
      */
     public void paintComponent(Graphics g) {
