@@ -86,7 +86,7 @@ import javax.swing.filechooser.FileFilter;
  *
  * @author Mark Hall (mhall@cs.waikato.ac.nz)
  * @author Malcolm Ware (mfw4@cs.waikato.ac.nz)
- * @version $Revision: 4753 $
+ * @version $Revision: 7406 $
  */
 public class VisualizePanel
   extends PrintablePanel {
@@ -335,8 +335,8 @@ public class VisualizePanel
 		    }
 		    m_shapes.addElement(m_shapePoints);
 
-		    m_submit.setText("Submit");
-		    m_submit.setActionCommand("Submit");
+		    m_submit.setText(Messages.getInstance().getString("VisualizePanel_PlotPanel_MouseClicked_Submit_SetText_Text_First"));
+		    m_submit.setActionCommand(Messages.getInstance().getString("VisualizePanel_PlotPanel_MouseClicked_Submit_SetActionCommand_Text_First"));
 		    
 		    m_submit.setEnabled(true);
 		  }
@@ -356,8 +356,8 @@ public class VisualizePanel
 		    }
 		    m_shapes.addElement(m_shapePoints);
 			   
-		    m_submit.setText("Submit");
-		    m_submit.setActionCommand("Submit");
+		    m_submit.setText(Messages.getInstance().getString("VisualizePanel_PlotPanel_MouseClicked_Submit_SetText_Text_Second"));
+		    m_submit.setActionCommand(Messages.getInstance().getString("VisualizePanel_PlotPanel_MouseClicked_Submit_SetActionCommand_Text_Second"));
 		    
 		    m_submit.setEnabled(true);
 		  }
@@ -459,8 +459,8 @@ public class VisualizePanel
 		    
 		    m_shapes.addElement(m_shapePoints);
 		    
-		    m_submit.setText("Submit");
-		    m_submit.setActionCommand("Submit");
+		    m_submit.setText(Messages.getInstance().getString("VisualizePanel_PlotPanel_MouseReleased_Submit_SetText_Text"));
+		    m_submit.setActionCommand(Messages.getInstance().getString("VisualizePanel_PlotPanel_MouseReleased_Submit_SetActionCommand_Text"));
 		    
 		    m_submit.setEnabled(true);
 
@@ -540,7 +540,7 @@ public class VisualizePanel
       m_submit.addActionListener(new ActionListener() {
 	  public void actionPerformed(ActionEvent e) {
 	 
-	    if (e.getActionCommand().equals("Submit")) {
+	    if (e.getActionCommand().equals(Messages.getInstance().getString("VisualizePanel_PlotPanel_ActionPerformed_Submit_ActionCommand_Text"))) {
 	      if (m_splitListener != null && m_shapes != null) {
 		//then send the split to the listener
 		Instances sub_set1 = new Instances(m_plot2D.getMasterPlot().
@@ -641,13 +641,13 @@ public class VisualizePanel
 		  VisualizePanel.this.setXIndex(x);
 		  VisualizePanel.this.setYIndex(y);
 		} catch(Exception er) {
-		  System.out.println("Error : " + er);
+		  System.out.println(Messages.getInstance().getString("VisualizePanel_PlotPanel_ActionPerformed_Error_Text_First") + er);
 		  //  System.out.println("Part of user input so had to" +
 		  //		 " catch here");
 		}
 	      }
 	    }
-	    else if (e.getActionCommand().equals("Reset")) {
+	    else if (e.getActionCommand().equals(Messages.getInstance().getString("VisualizePanel_PlotPanel_ActionPerformed_Reset_ActionCommand_Text"))) {
 	      int x = m_xIndex;
 	      int y = m_yIndex;
 
@@ -663,7 +663,7 @@ public class VisualizePanel
 		VisualizePanel.this.setXIndex(x);
 		VisualizePanel.this.setYIndex(y);
 	      } catch(Exception er) {
-		System.out.println("Error : " + er);
+		System.out.println(Messages.getInstance().getString("VisualizePanel_PlotPanel_ActionPerformed_Error_Text_Second") + er);
 	      }
 	    }
 	  }  
@@ -701,8 +701,8 @@ public class VisualizePanel
     public void cancelShapes() {
        
       if (m_splitListener == null) {
-	m_submit.setText("Reset");
-	m_submit.setActionCommand("Reset");
+	m_submit.setText(Messages.getInstance().getString("VisualizePanel_PlotPanel_CancelShapes_Submit_SetText_Text"));
+	m_submit.setActionCommand(Messages.getInstance().getString("VisualizePanel_PlotPanel_CancelShapes_Submit_SetActionCommand_Text"));
 
 	if (m_originalPlot == null || 
 	    m_originalPlot.m_plotInstances == m_plotInstances) {
@@ -1065,11 +1065,9 @@ public class VisualizePanel
 	    // more attributes than the panel can handle?
 	    // Due to hard coded constraints in GridBagLayout
 	    m_plotSurround.remove(m_attrib);
-	    System.err.println("Warning : data contains more attributes "
-			       +"than can be displayed as attribute bars.");
+	    System.err.println(Messages.getInstance().getString("VisualizePanel_PlotPanel_Error_Text_First"));
 	    if (m_Log != null) {
-	      m_Log.logMessage("Warning : data contains more attributes "
-			       +"than can be displayed as attribute bars.");
+	      m_Log.logMessage(Messages.getInstance().getString("VisualizePanel_PlotPanel_Log_LogMessage_Text_First"));
 	    }
 	  }
 	} else if (m_showAttBars) {
@@ -1084,25 +1082,23 @@ public class VisualizePanel
 	    constraints.weighty=5;
 	    m_plotSurround.add(m_attrib, constraints);
 	  } catch (Exception ex) {
-	    System.err.println("Warning : data contains more attributes "
-			       +"than can be displayed as attribute bars.");
+	    System.err.println(Messages.getInstance().getString("VisualizePanel_PlotPanel_Error_Text_Second"));
 	    if (m_Log != null) {
-	      m_Log.logMessage("Warning : data contains more attributes "
-			       +"than can be displayed as attribute bars.");
+	      m_Log.logMessage(Messages.getInstance().getString("VisualizePanel_PlotPanel_Log_LogMessage_Text_Second"));
 	    }
 	  }
 	}
 	m_classPanel.setInstances(newPlot.m_plotInstances);
 
 	plotReset(newPlot.m_plotInstances, newPlot.getCindex());
-	if (newPlot.m_useCustomColour) {
+	if (newPlot.m_useCustomColour && m_showClassPanel) {
 	  VisualizePanel.this.remove(m_classSurround);
 	  switchToLegend();
 	  m_legendPanel.setPlotList(m_plot2D.getPlots());
 	  m_ColourCombo.setEnabled(false);
 	}
       } else  {
-	if (!newPlot.m_useCustomColour) {
+	if (!newPlot.m_useCustomColour && m_showClassPanel) {
 	  VisualizePanel.this.add(m_classSurround, BorderLayout.SOUTH);
 	  m_ColourCombo.setEnabled(true);
 	}
@@ -1163,11 +1159,9 @@ public class VisualizePanel
           constraints.weighty=5;
           m_plotSurround.add(m_attrib, constraints);
         } catch (Exception ex) {
-          System.err.println("Warning : data contains more attributes "
-                             +"than can be displayed as attribute bars.");
+          System.err.println(Messages.getInstance().getString("VisualizePanel_PlotPanel_SwitchToBars_Error_Text"));
           if (m_Log != null) {
-            m_Log.logMessage("Warning : data contains more attributes "
-                             +"than can be displayed as attribute bars.");
+            m_Log.logMessage(Messages.getInstance().getString("VisualizePanel_PlotPanel_SwitchToBars_Log_LogMessage_Text"));
           }
         }
       }
@@ -1181,8 +1175,8 @@ public class VisualizePanel
      */
     private void plotReset(Instances inst, int cIndex) {
       if (m_splitListener == null) {
-	m_submit.setText("Reset");
-	m_submit.setActionCommand("Reset");
+	m_submit.setText(Messages.getInstance().getString("VisualizePanel_PlotPanel_PlotReset_Submit_SetText_Text"));
+	m_submit.setActionCommand(Messages.getInstance().getString("VisualizePanel_PlotPanel_PlotReset_Submit_SetActionCommand_Text"));
 	//if (m_origInstances == null || m_origInstances == inst) {
 	if (m_originalPlot == null || m_originalPlot.m_plotInstances == inst) {
 	  m_submit.setEnabled(false);
@@ -1623,16 +1617,16 @@ public class VisualizePanel
   protected JComboBox m_ShapeCombo = new JComboBox();
 
   /** Button for the user to enter the splits. */
-  protected JButton m_submit = new JButton("Submit");
+  protected JButton m_submit = new JButton(Messages.getInstance().getString("VisualizePanel_PlotPanel_Submit_JButton_Text"));
   
   /** Button for the user to remove all splits. */
-  protected JButton m_cancel = new JButton("Clear");
+  protected JButton m_cancel = new JButton(Messages.getInstance().getString("VisualizePanel_PlotPanel_Cancel_JButton_Text"));
 
   /** Button for the user to open the visualized set of instances */
-  protected JButton m_openBut = new JButton("Open");
+  protected JButton m_openBut = new JButton(Messages.getInstance().getString("VisualizePanel_PlotPanel_OpenBut_JButton_Text"));
 
   /** Button for the user to save the visualized set of instances */
-  protected JButton m_saveBut = new JButton("Save");
+  protected JButton m_saveBut = new JButton(Messages.getInstance().getString("VisualizePanel_PlotPanel_SaveBut_JButton_Text"));
 
   /** Stop the combos from growing out of control */
   private Dimension COMBO_SIZE = new Dimension(250, m_saveBut
@@ -1644,10 +1638,10 @@ public class VisualizePanel
 
   /** Filter to ensure only arff files are selected */  
   protected FileFilter m_ArffFilter =
-    new ExtensionFileFilter(Instances.FILE_EXTENSION, "Arff data files");
+    new ExtensionFileFilter(Instances.FILE_EXTENSION, Messages.getInstance().getString("VisualizePanel_PlotPanel_ArffFilter_FileFilter_Text"));
 
   /** Label for the jitter slider */
-  protected JLabel m_JitterLab= new JLabel("Jitter",SwingConstants.RIGHT);
+  protected JLabel m_JitterLab= new JLabel(Messages.getInstance().getString("VisualizePanel_PlotPanel_JitterLab_JLabel_Text"),SwingConstants.RIGHT);
 
   /** The jitter slider */
   protected JSlider m_Jitter = new JSlider(0,50,0);
@@ -1657,7 +1651,8 @@ public class VisualizePanel
 
   /** The panel that displays the attributes , using color to represent 
    * another attribute. */
-  protected AttributePanel m_attrib = new AttributePanel();
+  protected AttributePanel m_attrib = 
+    new AttributePanel(m_plot.m_plot2D.getBackground());
 
   /** The panel that displays legend info if there is more than one plot */
   protected LegendPanel m_legendPanel = new LegendPanel();
@@ -1681,7 +1676,8 @@ public class VisualizePanel
   protected String m_plotName = "";
 
   /** The panel that displays the legend for the colouring attribute */
-  protected ClassPanel m_classPanel = new ClassPanel();
+  protected ClassPanel m_classPanel = 
+    new ClassPanel(m_plot.m_plot2D.getBackground());
   
   /** The list of the colors used */
   protected FastVector m_colorList;
@@ -1694,6 +1690,9 @@ public class VisualizePanel
 
   /** Show the attribute bar panel */
   protected boolean m_showAttBars = true;
+  
+  /** Show the class panel **/
+  protected boolean m_showClassPanel = true;
 
   /** the logger */
   protected Logger m_Log;
@@ -1706,6 +1705,60 @@ public class VisualizePanel
   public void setLog(Logger newLog) {
     m_Log = newLog;
   }
+  
+  /**
+   * Set whether the attribute bars should be shown or not.
+   * If turned off via this method then any setting in the
+   * properties file (if exists) is ignored.
+   * 
+   * @param sab false if attribute bars are not to be displayed.
+   */
+  public void setShowAttBars(boolean sab) {
+    if (!sab && m_showAttBars) {
+      m_plotSurround.remove(m_attrib);
+    } else if (sab && !m_showAttBars) {
+      GridBagConstraints constraints = new GridBagConstraints();
+      constraints.insets = new Insets(0, 0, 0, 0);
+      constraints.gridx=4;constraints.gridy=0;constraints.weightx=1;
+      constraints.gridwidth=1;constraints.gridheight=1;constraints.weighty=5;
+      m_plotSurround.add(m_attrib, constraints);
+    }
+    m_showAttBars = sab;
+    repaint();
+  }
+  
+  /**
+   * Gets whether or not attribute bars are being displayed.
+   * 
+   * @return true if attribute bars are being displayed.
+   */
+  public boolean getShowAttBars() {
+    return m_showAttBars;
+  }
+  
+  /**
+   * Set whether the class panel should be shown or not.
+   * 
+   * @param scp false if class panel is not to be displayed
+   */
+  public void setShowClassPanel(boolean scp) {
+    if (!scp && m_showClassPanel) {
+      remove(m_classSurround);
+    } else if (scp && !m_showClassPanel) {
+      add(m_classSurround, BorderLayout.SOUTH);
+    }
+    m_showClassPanel = scp;
+    repaint();
+  }
+  
+  /**
+   * Gets whether or not the class panel is being displayed.
+   * 
+   * @return true if the class panel is being displayed.
+   */
+  public boolean getShowClassPanel() {
+    return m_showClassPanel;
+  }
 
   /** 
    * This constructor allows a VisualizePanelListener to be set. 
@@ -1733,13 +1786,16 @@ public class VisualizePanel
 	  getProperty(showAttBars);
 	if (val == null) {
 	  //System.err.println("Displaying attribute bars ");
-	  m_showAttBars = true;
+//	  m_showAttBars = true;
 	} else {
-	  if (val.compareTo("true") == 0 || val.compareTo("on") == 0) {
-	    //System.err.println("Displaying attribute bars ");
-	    m_showAttBars = true;
-	  } else {
-	    m_showAttBars = false;
+	  // only check if this hasn't been turned off programatically 
+	  if (m_showAttBars) {
+	    if (val.compareTo("true") == 0 || val.compareTo("on") == 0) {
+	      //System.err.println("Displaying attribute bars ");
+	      m_showAttBars = true;
+	    } else {
+	      m_showAttBars = false;
+	    }
 	  }
 	}
       } else {
@@ -1797,10 +1853,10 @@ public class VisualizePanel
     m_FileChooser.setFileFilter(m_ArffFilter);
     m_FileChooser.setFileSelectionMode(JFileChooser.FILES_ONLY);
 
-    m_XCombo.setToolTipText("Select the attribute for the x axis");
-    m_YCombo.setToolTipText("Select the attribute for the y axis");
-    m_ColourCombo.setToolTipText("Select the attribute to colour on");
-    m_ShapeCombo.setToolTipText("Select the shape to use for data selection"); 
+    m_XCombo.setToolTipText(Messages.getInstance().getString("VisualizePanel_XCombo_SetToolTipText_Text"));
+    m_YCombo.setToolTipText(Messages.getInstance().getString("VisualizePanel_YCombo_SetToolTipText_Text"));
+    m_ColourCombo.setToolTipText(Messages.getInstance().getString("VisualizePanel_ColourCombo_SetToolTipText_Text"));
+    m_ShapeCombo.setToolTipText(Messages.getInstance().getString("VisualizePanel_ShapeCombo_SetToolTipText_Text")); 
 
     m_XCombo.setPreferredSize(COMBO_SIZE);
     m_YCombo.setPreferredSize(COMBO_SIZE);
@@ -1826,6 +1882,24 @@ public class VisualizePanel
     // colours change
     m_classPanel.addRepaintNotify(this);
     m_legendPanel.addRepaintNotify(this);
+    
+    // Check the default colours against the background colour of the
+    // plot panel. If any are equal to the background colour then
+    // change them (so they are visible :-)
+    for (int i = 0; i < m_DefaultColors.length; i++) {
+      Color c = m_DefaultColors[i];
+      if (c.equals(m_plot.m_plot2D.getBackground())) {
+        int red = c.getRed();
+        int blue = c.getBlue();
+        int green = c.getGreen();
+        red += (red < 128) ? (255 - red) / 2 : -(red / 2);
+        blue += (blue < 128) ? (blue - red) / 2 : -(blue / 2);
+        green += (green< 128) ? (255 - green) / 2 : -(green / 2);
+        m_DefaultColors[i] = new Color(red, green, blue);
+      }
+    }
+    m_classPanel.setDefaultColourList(m_DefaultColors);
+    m_attrib.setDefaultColourList(m_DefaultColors);
 
     m_colorList = new FastVector(10);
     for (int noa = m_colorList.size(); noa < 10; noa++) {
@@ -1919,7 +1993,7 @@ public class VisualizePanel
 	}
       });
 
-    m_openBut.setToolTipText("Loads previously saved instances from a file");
+    m_openBut.setToolTipText(Messages.getInstance().getString("VisualizePanel_OpenBut_SetToolTipText_Text"));
     m_openBut.addActionListener(new ActionListener() {
 	public void actionPerformed(ActionEvent e) {
 	  openVisibleInstances();
@@ -1927,7 +2001,7 @@ public class VisualizePanel
       });
     
     m_saveBut.setEnabled(false);
-    m_saveBut.setToolTipText("Save the visible instances to a file");
+    m_saveBut.setToolTipText(Messages.getInstance().getString("VisualizePanel_SaveBut_SetToolTipText_Text"));
     m_saveBut.addActionListener(new ActionListener() {
 	public void actionPerformed(ActionEvent e) {
 	  saveVisibleInstances();
@@ -1983,14 +2057,14 @@ public class VisualizePanel
 
     m_classSurround = new JPanel();
     m_classSurround.
-      setBorder(BorderFactory.createTitledBorder("Class colour")); 
+      setBorder(BorderFactory.createTitledBorder(Messages.getInstance().getString("VisualizePanel_ClassSurround_BorderFactoryCreateTitledBorder_Text"))); 
     m_classSurround.setLayout(new BorderLayout());
 
     m_classPanel.setBorder(BorderFactory.createEmptyBorder(15,10,10,10));
     m_classSurround.add(m_classPanel, BorderLayout.CENTER);
 
     GridBagLayout gb2 = new GridBagLayout();
-    m_plotSurround.setBorder(BorderFactory.createTitledBorder("Plot"));
+    m_plotSurround.setBorder(BorderFactory.createTitledBorder(Messages.getInstance().getString("VisualizePanel_PlotSurround_BorderFactoryCreateTitledBorder_Text")));
     m_plotSurround.setLayout(gb2);
 
     constraints.fill = GridBagConstraints.BOTH;
@@ -2012,10 +2086,10 @@ public class VisualizePanel
     add(m_classSurround, BorderLayout.SOUTH);
     
     String [] SNames = new String [4];
-    SNames[0] = "Select Instance";
-    SNames[1] = "Rectangle";
-    SNames[2] = "Polygon";
-    SNames[3] = "Polyline";
+    SNames[0] = Messages.getInstance().getString("VisualizePanel_SNames_0_Text");
+    SNames[1] = Messages.getInstance().getString("VisualizePanel_SNames_1_Text");
+    SNames[2] = Messages.getInstance().getString("VisualizePanel_SNames_2_Text");
+    SNames[3] = Messages.getInstance().getString("VisualizePanel_SNames_3_Text");
 
     m_ShapeCombo.setModel(new DefaultComboBoxModel(SNames));
     m_ShapeCombo.setEnabled(true);
@@ -2039,9 +2113,9 @@ public class VisualizePanel
     while (parent != null) {
       if (parent instanceof JFrame) {
 	((JFrame) parent).setTitle(
-	    "Weka Classifier Visualize: " 
+			Messages.getInstance().getString("VisualizePanel_OpenVisibleInstances_JFrame_Text_First") 
 	    + insts.relationName() 
-	    + " (display only)");
+	    + Messages.getInstance().getString("VisualizePanel_OpenVisibleInstances_JFrame_Text_Second"));
 	break;
       }
       else {
@@ -2072,7 +2146,7 @@ public class VisualizePanel
       JOptionPane.showMessageDialog(
 	  this, 
 	  ex.getMessage(), 
-	  "Error loading file...", 
+	  Messages.getInstance().getString("VisualizePanel_OpenVisibleInstances_JOptionPane.showMessageDialog_Text"), 
 	  JOptionPane.ERROR_MESSAGE);
     }
   }
@@ -2138,7 +2212,7 @@ public class VisualizePanel
     if (index >= 0 && index < m_XCombo.getItemCount()) {
       m_XCombo.setSelectedIndex(index);
     } else {
-      throw new Exception("x index is out of range!");
+      throw new Exception(Messages.getInstance().getString("VisualizePanel_SetXIndex_Text"));
     }
   }
 
@@ -2159,7 +2233,7 @@ public class VisualizePanel
     if (index >= 0 && index < m_YCombo.getItemCount()) {
       m_YCombo.setSelectedIndex(index);
     } else {
-      throw new Exception("y index is out of range!");
+      throw new Exception(Messages.getInstance().getString("VisualizePanel_SetYIndex_Text"));
     }
   }
   
@@ -2197,7 +2271,7 @@ public class VisualizePanel
       m_ShapeCombo.setSelectedIndex(index);
     }
     else {
-      throw new Exception("s index is out of range!");
+      throw new Exception(Messages.getInstance().getString("VisualizePanel_SetSIndex_Text"));
     }
   }
 
@@ -2310,29 +2384,29 @@ public class VisualizePanel
     String [] YNames = new String [inst.numAttributes()];
     String [] CNames = new String [inst.numAttributes()];
     for (int i = 0; i < XNames.length; i++) {
-      String type = "";
+      String type = " ";
       switch (inst.attribute(i).type()) {
       case Attribute.NOMINAL:
-	type = " (Nom)";
+	type += Messages.getInstance().getString("VisualizePanel_SetUpComboBoxes_AttributeNOMINAL_Text");
 	break;
       case Attribute.NUMERIC:
-	type = " (Num)";
+	type += Messages.getInstance().getString("VisualizePanel_SetUpComboBoxes_AttributeNUMERIC_Text");
 	break;
       case Attribute.STRING:
-	type = " (Str)";
+	type += Messages.getInstance().getString("VisualizePanel_SetUpComboBoxes_AttributeSTRING_Text");
 	break;
       case Attribute.DATE:
-	type = " (Dat)";
+	type += Messages.getInstance().getString("VisualizePanel_SetUpComboBoxes_AttributeDATE_Text");
 	break;
       case Attribute.RELATIONAL:
-	type = " (Rel)";
+	type += Messages.getInstance().getString("VisualizePanel_SetUpComboBoxes_AttributeRELATIONAL_Text");
 	break;
       default:
-	type = " (???)";
+	type += Messages.getInstance().getString("VisualizePanel_SetUpComboBoxes_AttributeDEFAULT_Text");
       }
-      XNames[i] = "X: "+ inst.attribute(i).name()+type;
-      YNames[i] = "Y: "+ inst.attribute(i).name()+type;
-      CNames[i] = "Colour: "+ inst.attribute(i).name()+type;
+      XNames[i] = Messages.getInstance().getString("VisualizePanel_SetUpComboBoxes_XNames_Text") + " " + inst.attribute(i).name()+type;
+      YNames[i] = Messages.getInstance().getString("VisualizePanel_SetUpComboBoxes_YNames_Text") + " " + inst.attribute(i).name()+type;
+      CNames[i] = Messages.getInstance().getString("VisualizePanel_SetUpComboBoxes_CNames_Text") + " " + inst.attribute(i).name()+type;
       if (m_preferredXDimension != null) {
 	if (m_preferredXDimension.compareTo(inst.attribute(i).name()) == 0) {
 	  prefX = i;
@@ -2366,7 +2440,7 @@ public class VisualizePanel
       m_ColourCombo.setEnabled(true);
       m_ColourCombo.setSelectedIndex(inst.numAttributes()-1);
     }
-    m_plotSurround.setBorder((BorderFactory.createTitledBorder("Plot: "
+    m_plotSurround.setBorder((BorderFactory.createTitledBorder(Messages.getInstance().getString("VisualizePanel_SetUpComboBoxes_PlotSurround_BorderFactoryCreateTitledBorder_Text")
 			      +inst.relationName())));
     try {
       if (prefX != -1) {
@@ -2379,7 +2453,7 @@ public class VisualizePanel
 	m_ColourCombo.setSelectedIndex(prefC);
       }
     } catch (Exception ex) {
-      System.err.println("Problem setting preferred Visualization dimensions");
+      System.err.println(Messages.getInstance().getString("VisualizePanel_SetUpComboBoxes_Error_Text"));
     }
   }
 
@@ -2433,14 +2507,13 @@ public class VisualizePanel
   public static void main(String [] args) {
     try {
       if (args.length < 1) {
-	System.err.println("Usage : weka.gui.visualize.VisualizePanel "
-			   +"<dataset> [<dataset> <dataset>...]");
+	System.err.println(Messages.getInstance().getString("VisualizePanel_Main_Error_Text_First"));
 	System.exit(1);
       }
 
-      weka.core.logging.Logger.log(weka.core.logging.Logger.Level.INFO, "Logging started");
+      weka.core.logging.Logger.log(weka.core.logging.Logger.Level.INFO, Messages.getInstance().getString("VisualizePanel_Main_Logger_Text"));
       final javax.swing.JFrame jf = 
-	new javax.swing.JFrame("Weka Explorer: Visualize");
+	new javax.swing.JFrame(Messages.getInstance().getString("VisualizePanel_Main_JFrame_Text"));
       jf.setSize(500,400);
       jf.getContentPane().setLayout(new BorderLayout());
       final VisualizePanel sp = new VisualizePanel();
@@ -2456,7 +2529,7 @@ public class VisualizePanel
       jf.setVisible(true);
       if (args.length >= 1) {
 	for (int j = 0; j < args.length; j++) {
-	  System.err.println("Loading instances from " + args[j]);
+	  System.err.println(Messages.getInstance().getString("VisualizePanel_Main_Error_Text_Second") + args[j]);
 	  java.io.Reader r = new java.io.BufferedReader(
 			     new java.io.FileReader(args[j]));
 	  Instances i = new Instances(r);
@@ -2464,10 +2537,10 @@ public class VisualizePanel
 	  PlotData2D pd1 = new PlotData2D(i);
 	  
 	  if (j == 0) {
-	    pd1.setPlotName("Master plot");
+	    pd1.setPlotName(Messages.getInstance().getString("VisualizePanel_Main_Pd1_SetPlotName_Text_First"));
 	    sp.setMasterPlot(pd1);
 	  } else {
-	    pd1.setPlotName("Plot "+(j+1));
+	    pd1.setPlotName(Messages.getInstance().getString("VisualizePanel_Main_Pd1_SetPlotName_Text_Second")+(j+1));
 	    pd1.m_useCustomColour = true;
 	    pd1.m_customColour = (j % 2 == 0) ? Color.red : Color.blue; 
 	    sp.addPlot(pd1);
